<?php
/*
Plugin Name: Easy Event Calendar
Plugin URI: https://corefortress.net/downloads/event-calendar/
Description: Whether you are organizing events in-person or webinars, this plugin combines everything you need to professionally display your events on your website.
Version: 1.0
Author: CoreFortress
Text Domain: easy-event-calendar
Author URI: https://corefortress.net
Domain Path: /langs
License: GNU/GPLv3 https://www.gnu.org/licenses/gpl-3.0.html
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

//on activation
//defined global variables and constants here
global $coreftCalendar, $coreftCalendar_cache, $table_prefix, $wpdb;
$coreftCalendar       = get_option( 'coreftCalendar_options' );
$coreftCalendar_cache = get_option( 'coreftCalendar_cache' );
define( 'COREFT_CALENDAR_URL', plugins_url( '/', __FILE__ ) );
define( 'COREFT_CALENDAR_PATH', plugin_dir_path( __FILE__ ) );
define( 'COREFT_CALENDAR_TABLE_EVENTS', 'coreftCalendar_events' ); //events TABLE NAME
define( 'COREFT_CALENDAR_TABLE_CALENDARS', 'coreftCalendar_calendars' ); //calendar TABLE NAME
define( 'COREFT_CALENDAR_TABLE_BOOKING', 'coreftCalendar_booking' ); //booking TABLE NAME
define( 'COREFT_CALENDAR_TABLE_SPECIAL_DATES', 'coreftCalendar_special_dates' ); //special dates TABLE NAME
define( 'COREFT_CALENDAR_TABLE_SPECIAL_DATES_CALENDAR', 'coreftCalendar_special_dates_calendar' ); //special dates TABLE NAME
define( 'COREFT_CALENDAR_TABLE_SUBSCRIBERS_CALENDAR', 'coreftCalendar_subscribers_calendar' ); //special dates TABLE NAME

define( 'COREFT_CALENDAR_PAYMENTS_URL', 'http://codecanyon.net/item/wordpress-pro-event-calendar-payment-extension/9492899' );

define( "COREFT_CALENDAR_VER", "1.0.0", false );//Current Version of this plugin
if ( ! defined( 'COREFT_CALENDAR_PLUGIN_BASENAME' ) ) {
	define( 'COREFT_CALENDAR_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
}
if ( ! defined( 'COREFT_CALENDAR_CSS_DIR' ) ) {
	define( 'COREFT_CALENDAR_CSS_DIR', WP_PLUGIN_DIR . '/' . str_replace( basename( __FILE__ ), "", plugin_basename( __FILE__ ) ) . '/css/' );
}

add_action( 'init', 'coreft_calendar_rewrite_rules' );

function coreft_calendar_rewrite_rules() {
	add_rewrite_rule( 'calendar-rss\/?$', 'index.php?coreft_calendar_page=rss', 'top' );
	add_rewrite_rule( 'calendar-ical-feed\/?$', 'index.php?coreft_calendar_page=ical_feed', 'top' );
	add_rewrite_rule( 'calendar-ical-event\/?$', 'index.php?coreft_calendar_page=ical_event', 'top' );
	add_rewrite_rule( 'calendar-export-subscribers\/?$', 'index.php?coreft_calendar_page=export_subs', 'top' );
	add_rewrite_rule( 'calendar-export-bookings\/?$', 'index.php?coreft_calendar_page=export_bookings', 'top' );
}

add_filter( 'query_vars', 'coreft_calendar_query_vars' );

function coreft_calendar_query_vars( $query_vars ) {
	$query_vars[] = 'coreft_calendar_page';

	return $query_vars;
}

add_action( 'template_include', 'coreft_calendar_template' );

function coreft_calendar_template( $template ) {
	$coreftPage = get_query_var( 'coreft_calendar_page' );
	if ( $coreftPage != false ) {
		switch ( $coreftPage ) {
			case 'rss':
				return COREFT_CALENDAR_PATH . 'views/rss.php';
				break;
			case 'ical_feed':
				return COREFT_CALENDAR_PATH . 'views/ical_feed.php';
				break;
			case 'ical_event':
				return COREFT_CALENDAR_PATH . 'views/ical_event.php';
				break;
			case 'export_subs':
				return COREFT_CALENDAR_PATH . 'views/export_subs.php';
				break;
			case 'export_bookings':
				return COREFT_CALENDAR_PATH . 'views/export_bookings.php';
				break;
		}

	}

	return $template;
}


add_action( 'all_admin_notices', 'coreft_calendar_products_admin_screens_tabs' );

function coreft_calendar_products_admin_screens_tabs() {
	if ( ! is_admin() ) {
		return;
	}
	global $current_screen;

	if ( in_array( $current_screen->post_type, array( 'coreft-events', 'coreft-venues', 'coreft-organizers' ) ) ) {
		coreftCalendar_admin_scripts( true );
		require COREFT_CALENDAR_PATH . 'views' . DIRECTORY_SEPARATOR . 'admin' . DIRECTORY_SEPARATOR . 'pro-notice.php';
	}
}

add_action( 'wp_ajax_coreft_calendar_dismiss_pro_notice', 'coreft_catalog_dismiss_notice' );

function coreft_catalog_dismiss_notice() {
	set_transient( 'coreft_calendar_hide_notice', 'yes', 86400 );
}

function coreftCalendar_load_textdomain() {
// Create Text Domain For Translations

	//load_plugin_textdomain('coreftCalendar', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');

	$domain = 'coreftCalendar';
	$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

	load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
	//load_plugin_textdomain( $domain, FALSE, dirname( dirname( plugin_basename( __FILE__ ) ) ) . '/languages' );
	load_plugin_textdomain( 'coreftCalendar', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

}

add_action( 'plugins_loaded', 'coreftCalendar_load_textdomain' );

function checkMU_install_coreftCalendar( $network_wide ) {
	global $wpdb;
	if ( $network_wide ) {
		$blog_list = get_blog_list( 0, 'all' );
		foreach ( $blog_list as $blog ) {
			switch_to_blog( $blog['blog_id'] );
			install_coreftCalendar();
		}
		switch_to_blog( $wpdb->blogid );
	} else {
		install_coreftCalendar();
	}
}

function install_coreftCalendar() {
	global $wpdb, $table_prefix;
	$table_name_booking                = strtolower( $table_prefix . COREFT_CALENDAR_TABLE_BOOKING );
	$table_name_calendars              = strtolower( $table_prefix . COREFT_CALENDAR_TABLE_CALENDARS );
	$table_name_special_dates          = strtolower( $table_prefix . COREFT_CALENDAR_TABLE_SPECIAL_DATES );
	$table_name_special_dates_calendar = strtolower( $table_prefix . COREFT_CALENDAR_TABLE_SPECIAL_DATES_CALENDAR );
	$table_name_subscribers_calendar   = strtolower( $table_prefix . COREFT_CALENDAR_TABLE_SUBSCRIBERS_CALENDAR );


	if ( $wpdb->get_var( "show tables like '$table_name_booking'" ) != $table_name_booking ) {
		$sql = "CREATE TABLE $table_name_booking (
					id int(11) NOT NULL AUTO_INCREMENT,
					id_calendar int(11) NOT NULL,
					id_event int(11) NOT NULL,
					id_coupon int(11) NULL,
					coupon_discount int(11) NULL,
					booking_date datetime NOT NULL,
					cancel_date datetime NULL,
					event_date date NOT NULL,
					id_user int(11) NOT NULL,
					quantity int(11) NOT NULL DEFAULT 1,
					comment text NULL,
					cancel_reason text NULL,
					status varchar(255) NOT NULL,
					name varchar(255) NOT NULL,
					email varchar(255) NOT NULL,
					phone varchar(80) NULL,
					extra_fields TEXT NULL DEFAULT '',
					UNIQUE KEY id(id)
				) DEFAULT CHARSET utf8 COLLATE utf8_general_ci;";
		$rs  = $wpdb->query( $sql );
	}

	if ( $wpdb->get_var( "show tables like '$table_name_calendars'" ) != $table_name_calendars ) {
		$sql = "CREATE TABLE $table_name_calendars (
					id int(11) NOT NULL AUTO_INCREMENT,
					active tinyint(1) NOT NULL,
					title varchar(80) NOT NULL,
					description varchar(255) NOT NULL,
					width char(5) NOT NULL,
					width_unity char(2) NOT NULL DEFAULT 'px',
					default_date date NULL,
					date_range_start date NULL,
					date_range_end date NULL,
					ical_active tinyint(1) NOT NULL,
					ical_limit varchar(80) NOT NULL,
					rss_active tinyint(1) NOT NULL,
					rss_limit varchar(80) NOT NULL,
					link_post tinyint(1) NOT NULL,
					link_post_target varchar(80) NULL DEFAULT '_self',
					booking_display_attendees tinyint(1) NOT NULL DEFAULT 0,
					booking_display_attendees_names tinyint(1) NOT NULL DEFAULT 0,
					booking_display_fully_booked tinyint(1) NOT NULL DEFAULT 0,
					email_admin_new_event tinyint(1) NOT NULL,
					hide_old_dates TINYINT(1) NOT NULL DEFAULT 0,
					limit_time_start TINYINT(2) NOT NULL DEFAULT 0,
					limit_time_end TINYINT(2) NOT NULL DEFAULT 0,
					view VARCHAR(80) NOT NULL DEFAULT 'monthly',
					format_ampm TINYINT(1) NOT NULL DEFAULT 0,
					show_time TINYINT(1) NOT NULL DEFAULT 1,
					show_timezone TINYINT(1) NOT NULL DEFAULT 0,
					show_preview TINYINT(1) NOT NULL DEFAULT 0,
					show_titles_monthly TINYINT(1) NOT NULL DEFAULT 0,
					show_references TINYINT(1) NOT NULL DEFAULT 1,
					show_author TINYINT(1) NOT NULL DEFAULT 0,
					show_search TINYINT(1) NOT NULL DEFAULT 0,
					show_category_filter TINYINT(1) NOT NULL DEFAULT 0,
					show_location_filter TINYINT(1) NOT NULL DEFAULT 0,
					booking_enable TINYINT(1) NOT NULL DEFAULT 0,
					booking_non_logged TINYINT(1) NOT NULL DEFAULT 0,
					booking_cancel TINYINT(1) NOT NULL DEFAULT 0,
					booking_email_template_user TEXT NOT NULL,
					booking_email_template_admin TEXT NOT NULL,
					booking_email_template_reminder_user TEXT NOT NULL,
					booking_cancel_email_enable TINYINT(1) NOT NULL DEFAULT 0,
					booking_cancel_email_template TEXT NOT NULL,
					new_event_email_template_published TEXT NOT NULL,
					booking_comment TINYINT(1) NULL DEFAULT 0,
					booking_event_color VARCHAR(80) NOT NULL DEFAULT '#e14d43',
					category_filter_include text NULL,
					venue_filter_include text NULL,
					allow_user_add_event_roles text NULL,
					booking_custom_fields text NULL,
					form_custom_fields text NULL,
					article_share TINYINT(1) NOT NULL DEFAULT 0,
					cache_active TINYINT(1) NOT NULL DEFAULT 0,
					allow_user_add_event TINYINT(1) NOT NULL DEFAULT 0,
					publish_new_event TINYINT(1) NOT NULL DEFAULT 0,
					new_event_email_enable TINYINT(1) NOT NULL DEFAULT 1,
					form_text_editor TINYINT(1) NOT NULL DEFAULT 1,
					form_show_end_date TINYINT(1) NOT NULL DEFAULT 1,
					form_show_start_time TINYINT(1) NOT NULL DEFAULT 1,
					form_show_end_time TINYINT(1) NOT NULL DEFAULT 1,
					form_show_extra_dates TINYINT(1) NOT NULL DEFAULT 0,
					form_show_description TINYINT(1) NOT NULL DEFAULT 1,
					form_show_category TINYINT(1) NOT NULL DEFAULT 1,
					form_show_hide_time TINYINT(1) NOT NULL DEFAULT 1,
					form_show_frequency TINYINT(1) NOT NULL DEFAULT 1,
					form_show_all_day TINYINT(1) NOT NULL DEFAULT 1,
					form_show_image TINYINT(1) NOT NULL DEFAULT 1,
					form_show_link TINYINT(1) NOT NULL DEFAULT 1,
					form_show_location TINYINT(1) NOT NULL DEFAULT 1,
					form_show_location_options TINYINT(1) NOT NULL DEFAULT 0,					
					form_show_phone TINYINT(1) NOT NULL DEFAULT 1,
					form_show_map TINYINT(1) NOT NULL DEFAULT 1,
					form_show_color TINYINT(1) NOT NULL DEFAULT 0,
					form_show_timezone TINYINT(1) NOT NULL DEFAULT 0,
					form_show_booking_enable TINYINT(1) NOT NULL DEFAULT 0,
					form_show_booking_limit TINYINT(1) NOT NULL DEFAULT 0,
					form_show_booking_price TINYINT(1) NOT NULL DEFAULT 0,
					form_show_booking_block_hours TINYINT(1) NOT NULL DEFAULT 0,
					show_x TINYINT(1) NOT NULL DEFAULT 1,
					allow_user_edit_event TINYINT(1) NOT NULL DEFAULT 0,
					allow_user_remove_event TINYINT(1) NOT NULL DEFAULT 0,
					show_view_buttons TINYINT(1) NOT NULL DEFAULT 1,
					assign_events_admin INT(11) NOT NULL DEFAULT 0,
					first_day tinyint(1) NOT NULL DEFAULT '0',
					current_date_color VARCHAR(10) NOT NULL DEFAULT '#C4C5D1',
					subscribe_active tinyint(1) NOT NULL DEFAULT 0,
					mailchimp_api varchar(80) NULL,
					mailchimp_list varchar(80) NULL,
					translation_fields TEXT NULL DEFAULT '',
					skin varchar(80) NOT NULL,
					enable_wpml TINYINT(1) NOT NULL DEFAULT 0,
					sync_ical_enable TINYINT(1) NOT NULL DEFAULT 0,
					sync_ical_url TEXT NOT NULL DEFAULT '',
					sync_ical_frequency VARCHAR(80) NOT NULL DEFAULT '',
					sync_ical_category INT(11) NOT NULL DEFAULT 0,
					sync_fb_page TEXT NOT NULL DEFAULT '',
					daily_weekly_layout VARCHAR(80) NOT NULL DEFAULT 'list',
					booking_max_quantity INT(11) NOT NULL DEFAULT 3,
					booking_max_upcoming_dates INT(11) NOT NULL DEFAULT 10,
					booking_show_phone TINYINT(1) NOT NULL DEFAULT 0,
					booking_show_remaining TINYINT(1) NOT NULL DEFAULT 1,
					UNIQUE KEY id(id)
				) DEFAULT CHARSET utf8 COLLATE utf8_general_ci;";
		$rs  = $wpdb->query( $sql );
	}

	if ( $wpdb->get_var( "show tables like '$table_name_special_dates'" ) != $table_name_special_dates ) {
		$sql = "CREATE TABLE $table_name_special_dates (
					id int(11) NOT NULL AUTO_INCREMENT,
					title varchar(80) NOT NULL,
					color varchar(10) NOT NULL,
					UNIQUE KEY id(id)
				) DEFAULT CHARSET utf8 COLLATE utf8_general_ci;";
		$rs  = $wpdb->query( $sql );
	}

	if ( $wpdb->get_var( "show tables like '$table_name_special_dates_calendar'" ) != $table_name_special_dates_calendar ) {
		$sql = "CREATE TABLE $table_name_special_dates_calendar (
					special_date int(11) NOT NULL,
					calendar int(11) NOT NULL,
					date date NOT NULL,
					PRIMARY KEY (special_date,calendar,date)
				) DEFAULT CHARSET utf8 COLLATE utf8_general_ci;";
		$rs  = $wpdb->query( $sql );
	}

	if ( $wpdb->get_var( "show tables like '$table_name_subscribers_calendar'" ) != $table_name_subscribers_calendar ) {
		$sql = "CREATE TABLE $table_name_subscribers_calendar (
					id int(11) NOT NULL AUTO_INCREMENT,
					calendar int(11) NOT NULL,
					name varchar(80) NOT NULL,
					email varchar(80) NOT NULL,
					subscription_date datetime NOT NULL,
					UNIQUE KEY id(id)
				) DEFAULT CHARSET utf8 COLLATE utf8_general_ci;";
		$rs  = $wpdb->query( $sql );
	}

	$default_events = array();
	$default_events = array(

		'version'                              => COREFT_CALENDAR_VER,
		'disable_rewrite_rules'                => 0,
		'user_roles'                           => array(),
		'article_share'                        => true,
		'category_filter_include'              => true,
		'assign_events_admin'                  => true,
		'all_working_days'                     => true,
		'hide_old_dates'                       => true,
		'limit_time_start'                     => true,
		'form_show_fields'                     => true,
		'allow_users_edit_event'               => true,
		'show_author'                          => true,
		'remove_events'                        => true,
		'cache_active'                         => true,
		'booking'                              => true,
		'booking_lang'                         => true,
		'enable_wpml'                          => true,
		'booking_status'                       => true,
		'booking_non_logged'                   => true,
		'booking_non_logged_options'           => true,
		'weekly_view'                          => true,
		'tickets_remaining'                    => true,
		'sync_ical'                            => true,
		'updatebookingtable'                   => true,
		'show_titles_monthly'                  => true,
		'daily_weekly_layout'                  => true,
		'allow_user_add_event_roles'           => true,
		'sync_ical_url_text'                   => true,
		'display_attendees'                    => true,
		'new_event_template_published'         => true,
		'booking_quantity'                     => true,
		'booking_max_quantity'                 => true,
		'form_text_editor'                     => true,
		'form_bookings'                        => true,
		'booking_max_upcoming_dates'           => true,
		'booking_phone'                        => true,
		'form_show_color'                      => true,
		'booking_email_template_reminder_user' => true,
		'booking_extra_fields'                 => true,
		'sync_fb_page'                         => true,
		'translation_fields'                   => true,
		'sync_ical_category'                   => true,
		'show_timezone_update'                 => true,
		'form_show_end_time'                   => true,
		'display_attendees_names'              => true,
		'show_location_filter'                 => true,
		'form_show_location_options'           => true,
		'link_post_target'                     => true,
		'booking_cancel'                       => true,
		'booking_cancel_date'                  => true,
		'new_event_email_enable'               => true,
		'booking_cancel_reason'                => true,
		'booking_cancel_email_enable'          => true,
		'booking_coupon'                       => true,
		'booking_remaining'                    => true,
		'form_show_timezone'                   => true,
		'form_show_extra_dates'                => true,
		'booking_custom_fields_calendar'       => true,
		'venue_filter_include'                 => true,
		'display_fully_booked'                 => true,
		'form_show_booking_block_hours'        => true,
		'update_sync_ical_type_'               => true,
		'redirect_archive'                     => '',
		'wp_mail_from'                         => '',
		'custom_css'                           => '',
		'rtl_support'                          => false,
		'exclude_gmaps'                        => true,
		'disable_reminders'                    => true,
		'google_map_key'                       => '',
		'map_marker'                           => '',
		'map_default_location'                 => '',
		'map_default_latlng'                   => '',
		'facebook_app_id'                      => '',
		'facebook_app_secret'                  => '',
		'recaptcha_enable'                     => false,
		'recaptcha_site_key'                   => '',
		'recaptcha_secret_key'                 => '',
		'remove_expired_enable'                => false,
	);

	$coreftCalendar = get_option( 'coreftCalendar_options' );

	if ( ! $coreftCalendar ) {
		$coreftCalendar = array();
	}

	foreach ( $default_events as $key => $value ) {
		if ( ! isset( $coreftCalendar[ $key ] ) ) {
			$coreftCalendar[ $key ] = $value;
		}
	}

	delete_option( 'coreftCalendar_options' );
	update_option( 'coreftCalendar_options', $coreftCalendar );
}

register_activation_hook( __FILE__, 'checkMU_install_coreftCalendar' );

/* Uninstall */
function checkMU_uninstall_coreftCalendar( $network_wide ) {
	global $wpdb;
	if ( $network_wide ) {
		$blog_list = get_blog_list( 0, 'all' );
		foreach ( $blog_list as $blog ) {
			switch_to_blog( $blog['blog_id'] );
			uninstall_coreftCalendar();
		}
		switch_to_blog( $wpdb->blogid );
	} else {
		uninstall_coreftCalendar();
	}
}

function uninstall_coreftCalendar() {
	global $wpdb, $table_prefix;
	delete_option( 'coreftCalendar_options' );

	$events_table = $table_prefix . COREFT_CALENDAR_TABLE_EVENTS;
	$sql          = "DROP TABLE $events_table;";
	$wpdb->query( $sql );

	$calendars_table = $table_prefix . COREFT_CALENDAR_TABLE_CALENDARS;
	$sql             = "DROP TABLE $calendars_table;";
	$wpdb->query( $sql );

	$booking_table = $table_prefix . COREFT_CALENDAR_TABLE_BOOKING;
	$sql           = "DROP TABLE $booking_table;";
	$wpdb->query( $sql );

	$special_dates_table = $table_prefix . COREFT_CALENDAR_TABLE_SPECIAL_DATES;
	$sql                 = "DROP TABLE $special_dates_table;";
	$wpdb->query( $sql );

	$special_dates_calendar_table = $table_prefix . COREFT_CALENDAR_TABLE_SPECIAL_DATES_CALENDAR;
	$sql                          = "DROP TABLE $special_dates_calendar_table;";
	$wpdb->query( $sql );

	$subscribers_calendar_table = $table_prefix . COREFT_CALENDAR_TABLE_SUBSCRIBERS_CALENDAR;
	$sql                        = "DROP TABLE $subscribers_calendar_table;";
	$wpdb->query( $sql );
}

register_uninstall_hook( __FILE__, 'checkMU_uninstall_coreftCalendar' );

/* Add new Blog */

add_action( 'wpmu_new_blog', 'newBlog_coreftCalendar', 10, 6 );

function newBlog_coreftCalendar( $blog_id, $user_id, $domain, $path, $site_id, $meta ) {
	global $wpdb;

	if ( is_plugin_active_for_network( 'coreftCalendar/coreftCalendar.php' ) ) {
		$old_blog = $wpdb->blogid;
		switch_to_blog( $blog_id );
		install_coreftCalendar();
		switch_to_blog( $old_blog );
	}
}

require_once( dirname( __FILE__ ) . '/src/functions.php' );
require_once( dirname( __FILE__ ) . '/src/core.php' );
require_once( dirname( __FILE__ ) . '/src/settings.php' );
require_once( dirname( __FILE__ ) . '/src/mailchimp/miniMCAPI.class.php' );


register_deactivation_hook( __FILE__, 'flush_rewrite_rules' );
register_activation_hook( __FILE__, 'coreftCalendar_flush_rewrites' );
function coreftCalendar_flush_rewrites() {
	global $coreftCalendar;
	if ( ! isset( $coreftCalendar['disable_rewrite_rules'] ) || ! $coreftCalendar['disable_rewrite_rules'] ) {
		coreftCalendar_pro_event_calendar_init();
	}

	flush_rewrite_rules();
}

//add_action( 'admin_init', 'flush_rewrite_rules' );

/*******************/
/* UPDATES 
/*******************/

$table_name_calendars              = $table_prefix . COREFT_CALENDAR_TABLE_CALENDARS;
$table_name_events                 = $table_prefix . COREFT_CALENDAR_TABLE_EVENTS;
$table_name_booking                = $table_prefix . COREFT_CALENDAR_TABLE_BOOKING;
$table_name_special_dates          = $table_prefix . COREFT_CALENDAR_TABLE_SPECIAL_DATES;
$table_name_special_dates_calendar = $table_prefix . COREFT_CALENDAR_TABLE_SPECIAL_DATES_CALENDAR;
$table_name_subscribers_calendar   = $table_prefix . COREFT_CALENDAR_TABLE_SUBSCRIBERS_CALENDAR;


if ( ! isset( $coreftCalendar['update_sync_ical_type_'] ) ) {

	if ( ! isset( $coreftCalendar['update_sync_ical_type_'] ) ) {
		$coreftCalendar['update_sync_ical_type_'] = true;

		$sql = "ALTER TABLE $table_name_calendars MODIFY sync_ical_category int(11) NOT NULL DEFAULT 0;";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_show_booking_block_hours'] ) ) {
		$coreftCalendar['form_show_booking_block_hours'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_booking_block_hours TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['display_fully_booked'] ) ) {
		$coreftCalendar['display_fully_booked'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_display_fully_booked TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['venue_filter_include'] ) ) {
		$coreftCalendar['venue_filter_include'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (venue_filter_include text NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_show_extra_dates'] ) ) {
		$coreftCalendar['form_show_extra_dates'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_extra_dates TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_custom_fields_calendar'] ) ) {
		$coreftCalendar['booking_custom_fields_calendar'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_custom_fields text NULL);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_custom_fields text NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_show_timezone'] ) ) {
		$coreftCalendar['form_show_timezone'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_timezone TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_remaining'] ) ) {
		$coreftCalendar['booking_remaining'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_show_remaining TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_cancel_email_enable'] ) ) {

		$coreftCalendar['booking_cancel_email_enable'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_cancel_email_enable TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_cancel_email_template TEXT NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['new_event_email_enable'] ) ) {
		$coreftCalendar['new_event_email_enable'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (new_event_email_enable TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_cancel'] ) ) {
		$coreftCalendar['booking_cancel'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_cancel TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['link_post_target'] ) ) {
		$coreftCalendar['link_post_target'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (link_post_target varchar(80) NULL DEFAULT '_self');";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );

	}

	if ( ! isset( $coreftCalendar['form_show_location_options'] ) ) {
		$coreftCalendar['form_show_location_options'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_location_options TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['show_location_filter'] ) ) {
		$coreftCalendar['show_location_filter'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (show_location_filter TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['display_attendees_names'] ) ) {
		$coreftCalendar['display_attendees_names'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_display_attendees_names TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_show_end_time'] ) ) {
		$coreftCalendar['form_show_end_time'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_end_date TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_start_time TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_end_time TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['show_timezone_update'] ) ) {
		$coreftCalendar['show_timezone_update'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (show_timezone TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['sync_ical_category'] ) ) {
		$coreftCalendar['sync_ical_category'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (sync_ical_category INT(11) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['translation_fields'] ) ) {
		$coreftCalendar['translation_fields'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (translation_fields TEXT NULL DEFAULT '');";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['sync_fb_page'] ) ) {
		$coreftCalendar['sync_fb_page'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (sync_fb_page TEXT NOT NULL DEFAULT '');";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_email_template_reminder_user'] ) ) {
		$coreftCalendar['booking_email_template_reminder_user'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_email_template_reminder_user TEXT NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_show_color'] ) ) {
		$coreftCalendar['form_show_color'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_color TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_max_upcoming_dates'] ) ) {
		$coreftCalendar['booking_max_upcoming_dates'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_max_upcoming_dates INT(11) NOT NULL DEFAULT 10);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_bookings'] ) ) {
		$coreftCalendar['form_bookings'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_booking_enable TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_booking_limit TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_booking_price TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_text_editor'] ) ) {
		$coreftCalendar['form_text_editor'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_text_editor TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_max_quantity'] ) ) {
		$coreftCalendar['booking_max_quantity'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_max_quantity INT(11) NOT NULL DEFAULT 3);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['new_event_template_published'] ) ) {
		$coreftCalendar['new_event_template_published'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (new_event_email_template_published TEXT NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['display_attendees'] ) ) {
		$coreftCalendar['display_attendees'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_display_attendees TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['allow_user_add_event_roles'] ) ) {
		$coreftCalendar['allow_user_add_event_roles'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (allow_user_add_event_roles text NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['daily_weekly_layout'] ) ) {
		$coreftCalendar['daily_weekly_layout'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (daily_weekly_layout VARCHAR(80) NOT NULL DEFAULT 'schedule');";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['show_titles_monthly'] ) ) {
		$coreftCalendar['show_titles_monthly'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (show_titles_monthly TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking'] ) ) {
		$coreftCalendar['booking'] = true;

		$sql = "CREATE TABLE $table_name_booking (
					id int(11) NOT NULL AUTO_INCREMENT,
					id_calendar int(11) NOT NULL,
					id_event int(11) NOT NULL,
					booking_date datetime NOT NULL,
					event_date date NOT NULL,
					id_user int(11) NOT NULL,
					comment text NULL,
					UNIQUE KEY id(id)
				) DEFAULT CHARSET utf8 COLLATE utf8_general_ci;";
		$rs  = $wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_coupon'] ) ) {
		$coreftCalendar['booking_coupon'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (id_coupon int(11) NULL);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_booking ADD (coupon_discount int(11) NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_cancel_reason'] ) ) {
		$coreftCalendar['booking_cancel_reason'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (cancel_reason text NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_extra_fields'] ) ) {
		$coreftCalendar['booking_extra_fields'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (extra_fields TEXT NULL DEFAULT '');";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_phone'] ) ) {
		$coreftCalendar['booking_phone'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (phone VARCHAR(80) NULL DEFAULT '');";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_show_phone TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_cancel_date'] ) ) {
		$coreftCalendar['booking_cancel_date'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (cancel_date datetime NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_quantity'] ) ) {
		$coreftCalendar['booking_quantity'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (quantity INT(11) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['updatebookingtable'] ) ) {
		$coreftCalendar['updatebookingtable'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (name varchar(255) NOT NULL);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_booking ADD (email varchar(255) NOT NULL);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_booking ADD (status varchar(255) NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['sync_ical'] ) ) {
		$coreftCalendar['sync_ical'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (sync_ical_enable TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (sync_ical_url VARCHAR(255) NOT NULL DEFAULT '');";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (sync_ical_frequency VARCHAR(80) NOT NULL DEFAULT '');";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['sync_ical_url_text'] ) ) {
		$coreftCalendar['sync_ical_url_text'] = true;

		$sql = "ALTER TABLE $table_name_calendars MODIFY sync_ical_url TEXT NOT NULL DEFAULT '';";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_non_logged_options'] ) ) {
		$coreftCalendar['booking_non_logged_options'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (name varchar(255) NOT NULL);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_booking ADD (email varchar(255) NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_non_logged'] ) ) {
		$coreftCalendar['booking_non_logged'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_non_logged TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_email_template_user TEXT NOT NULL);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_email_template_admin TEXT NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_status'] ) ) {
		$coreftCalendar['booking_status'] = true;

		$sql = "ALTER TABLE $table_name_booking ADD (status varchar(255) NOT NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['enable_wpml'] ) ) {
		$coreftCalendar['enable_wpml'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (enable_wpml TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['booking_lang'] ) ) {
		$coreftCalendar['booking_lang'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (booking_enable TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );
		$sql = "ALTER TABLE $table_name_calendars ADD (booking_comment TINYINT(1) NULL DEFAULT 0);";
		$wpdb->query( $sql );
		$sql = "ALTER TABLE $table_name_calendars ADD (booking_event_color VARCHAR(80) NOT NULL DEFAULT '#e14d43');";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}


	if ( ! isset( $coreftCalendar['cache_active'] ) ) {
		$coreftCalendar['cache_active'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (cache_active TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['remove_events'] ) ) {
		$coreftCalendar['remove_events'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (allow_user_remove_event TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['show_author'] ) ) {
		$coreftCalendar['show_author'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (show_author TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['allow_users_edit_event'] ) ) {
		$coreftCalendar['allow_users_edit_event'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (allow_user_edit_event TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['form_show_fields'] ) ) {
		$coreftCalendar['form_show_fields'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_description TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_category TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_hide_time TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_frequency TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_all_day TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_image TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_link TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_location TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_phone TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (form_show_map TINYINT(1) NOT NULL DEFAULT 1);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['limit_time_start'] ) ) {
		$coreftCalendar['limit_time_start'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (limit_time_start TINYINT(2) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		$sql = "ALTER TABLE $table_name_calendars ADD (limit_time_end TINYINT(2) NOT NULL DEFAULT 23);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['hide_old_dates'] ) ) {
		$coreftCalendar['hide_old_dates'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (hide_old_dates TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['assign_events_admin'] ) ) {
		$coreftCalendar['assign_events_admin'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (assign_events_admin INT(11) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['category_filter_include'] ) ) {
		$coreftCalendar['category_filter_include'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (category_filter_include text NULL);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}

	if ( ! isset( $coreftCalendar['article_share'] ) ) {
		$coreftCalendar['article_share'] = true;

		$sql = "ALTER TABLE $table_name_calendars ADD (article_share TINYINT(1) NOT NULL DEFAULT 0);";
		$wpdb->query( $sql );

		update_option( 'coreftCalendar_options', $coreftCalendar );
	}
}

function coreftSanitizeData( $data, $type = '' ) {
	if ( $type === 'absint' ) {
		return absint( $data );
	} elseif ( $type === 'content' ) {
		return wp_kses_post( $data );
	} elseif ( $type === 'email' ) {
		return sanitize_email( $data );
	} elseif ( $type === 'url' ) {
		return esc_url( $data );
	} elseif ( $type === 'string' || is_string( $data ) ) {
		return sanitize_text_field( $data );
	} elseif ( $type === 'array' || is_array( $data ) ) {
		foreach ( $data as $key => $value ) {
			if ( is_array( $value ) ) {
				$data[ $key ] = coreftSanitizeData( $value );
			} elseif ( is_string( $data ) ) {
				$data[ $key ] = sanitize_text_field( $value );
			}
		}

		return $data;
	} else {
		return $data;
	}
}

add_action('wp_ajax_coreft_calendar_mailchimp_getlists','coreft_calendar_mailchimp_getlists');

function coreft_calendar_mailchimp_getlists() {
	if($_POST['mailchimp_api']!=''){
		$api_key = coreftSanitizeData($_POST['mailchimp_api']);
		$return = '';
		//$mailchimp_class = new mailchimpSF_MCAPI($_POST['mailchimp_api']);

		//$retval = $mailchimp_class->lists();

		// Query String Perameters are here
		// for more reference please vizit http://developer.mailchimp.com/documentation/mailchimp/reference/lists/
		$data = array(
			'fields' => 'lists' // total_items, _links
		);

		$url = 'https://' . substr($api_key,strpos($api_key,'-')+1) . '.api.mailchimp.com/3.0/lists/';
		$result = coreftCalendar_mailchimp_curl_connect($url, 'GET', $api_key, $data);

		if( is_array( $result ) && ! is_wp_error( $result ) && isset($result->lists) && !empty($result->lists) ) {
			$return .= '<select name="mailchimp_list">';
			foreach( $result->lists as $list ){

				$return .= '<option value="'.$list->id.'">'.$list->name.'</option>';

			}
			$return .= '</select>';
		} else {
			$return = "Error: No lists found";
		}

		die($return);
	}
}

function coreftCalendar_mailchimp_curl_connect( $url, $request_type, $api_key, $data = array() ) {
	if( $request_type == 'GET' ){

		$url .= '?' . http_build_query($data);

		$response = wp_remote_get($url, array(
			'headers' => array(
				'Content-Type: application/json',
				'Authorization: Basic '.base64_encode( 'user:'. $api_key )
			)
		));
	} elseif($request_type == 'POST') {
		$response = wp_remote_post($url, array(
			'headers' => array(
				'Content-Type: application/json',
				'Authorization: Basic '.base64_encode( 'user:'. $api_key )
			),
			'body' => $data
		));

	} else {
		return false;
	}

	$responseBody = wp_remote_retrieve_body( $response );
	return json_decode( $responseBody );
}

?>