<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Adds meta boxes to the events
 *
 */

function coreftCalendar_remove_meta_boxes( $context = 'advanced', $priority = 'default' ) {
    global $wp_meta_boxes;

    $screens = array("coreft-venues", "coreft-organizers");
    foreach($screens as $screen) {
        $screen = convert_to_screen( $screen );
	    

	    $page = $screen->id;
	    
	    if(isset($wp_meta_boxes[$page]) && isset($wp_meta_boxes[$page][$context]) && isset($wp_meta_boxes[$page][$context][$priority])) {
		    if(is_array($wp_meta_boxes[$page][$context][$priority])) {
			    foreach($wp_meta_boxes[$page][$context][$priority] as $key) {
			    	
				    unset( $wp_meta_boxes[$page][$context][$priority][$key['id']] );

				}
			}
		}
	}

}

function coreftCalendar_meta_box_add() {
	add_meta_box( 'coreftCalendar_booking_meta', __('Booking', 'coreftCalendar'), 'coreftCalendar_booking_display', 'coreft-events', 'normal', 'high' );
	add_meta_box( 'coreftCalendar_events_meta', __('Event Data', 'coreftCalendar'), 'coreftCalendar_events_display', 'coreft-events', 'normal', 'high' );
	add_meta_box( 'coreftCalendar_excerpt_meta', __('Excerpt', 'coreftCalendar'), 'coreftCalendar_excerpt_display', 'coreft-events', 'normal', 'high' );
	add_meta_box( 'coreftCalendar_events_side_meta', __('Event Date Info', 'coreftCalendar'), 'coreftCalendar_events_side_display', 'coreft-events', 'side', 'high' );
	
	coreftCalendar_remove_meta_boxes('side', 'default');
	coreftCalendar_remove_meta_boxes('normal', 'default');
	coreftCalendar_remove_meta_boxes('normal', 'high');
	coreftCalendar_remove_meta_boxes('advanced', 'default');

	add_meta_box( 'coreftCalendar_events_meta', __('Venue Data', 'coreftCalendar'), 'coreftCalendar_venues_data_display', 'coreft-venues', 'normal', 'high' );
}
add_action( 'add_meta_boxes', 'coreftCalendar_meta_box_add', 20 );

function coreftCalendar_meta_box_remove() {
	remove_meta_box('slugdiv', 'coreft-venues', 'normal');
	
}
add_action( 'admin_menu', 'coreftCalendar_meta_box_remove' );

function coreftCalendar_meta_box_save( $post_id ) {
	global $wpdb, $coreftCalendar, $table_prefix;
	
	$table_name_booking = $table_prefix.COREFT_CALENDAR_TABLE_BOOKING;
	$table_name_calendars = $table_prefix.COREFT_CALENDAR_TABLE_CALENDARS;
	
	// Bail if we're doing an auto save
	if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;

	// if our nonce isn't there, or we can't verify it, bail
	if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'my_meta_box_nonce' ) ) return;

	// if our current user can't edit this post, bail
	if( !current_user_can( 'edit_post' ) ) return;

	// now we can actually save the data
	$allowed = array(
		'a' => array( // on allow a tags
			'href' => array() // and those anchors can only have href attribute
		)
	);

	if(get_post_type($post_id) == 'coreft-venues') {
		update_post_meta( $post_id, 'coreft_venue_address', wp_kses( $_POST['coreft_venue_address'], $allowed ) );
		update_post_meta( $post_id, 'coreft_venue_phone', wp_kses( $_POST['coreft_venue_phone'], $allowed ) );
		update_post_meta( $post_id, 'coreft_venue_link', wp_kses( $_POST['coreft_venue_link'], $allowed ) );

		update_post_meta( $post_id, 'coreft_venue_map', wp_kses( $_POST['coreft_venue_map'], $allowed ) );
		update_post_meta( $post_id, 'coreft_venue_map_lnlat', wp_kses( $_POST['coreft_venue_map_lnlat'], $allowed ) );
	}

	if(get_post_type($post_id) == 'coreft-events') {

		// make sure data is set, if author has removed the field or not populated it, delete it
		if( isset( $_POST['coreft_all_day'] ) && $_POST['coreft_all_day'] != '' ) {
			update_post_meta( $post_id, 'coreft_all_day', wp_kses( $_POST['coreft_all_day'], $allowed ) );
		} else {
			delete_post_meta($post_id, 'coreft_all_day');
		};
		
		if( isset( $_POST['coreft_tbc'] ) && $_POST['coreft_tbc'] != '' ) {
			update_post_meta( $post_id, 'coreft_tbc', wp_kses( $_POST['coreft_tbc'], $allowed ) );
		} else {
			delete_post_meta($post_id, 'coreft_tbc');
		};

		if( isset( $_POST['coreft_hide_time'] ) && $_POST['coreft_hide_time'] != '' ) {
			update_post_meta( $post_id, 'coreft_hide_time', wp_kses( $_POST['coreft_hide_time'], $allowed ) );
		} else {
			delete_post_meta($post_id, 'coreft_hide_time');
		};
		if( isset( $_POST['coreft_id_calendar'] ) && $_POST['coreft_id_calendar'] != '' ) {
			update_post_meta( $post_id, 'coreft_id_calendar', wp_kses( $_POST['coreft_id_calendar'], $allowed ) );
		} else {
			delete_post_meta($post_id, 'coreft_id_calendar');
		};

		$calendar_list = explode(",", $_POST['coreft_id_calendar']);
		
		update_post_meta( $post_id, 'coreft_enable_booking', wp_kses( $_POST['coreft_enable_booking'], $allowed ) );
		update_post_meta( $post_id, 'coreft_booking_continuous', wp_kses( $_POST['coreft_booking_continuous'], $allowed ) );
		update_post_meta( $post_id, 'coreft_show_limit', wp_kses( $_POST['coreft_show_limit'], $allowed ) );
		update_post_meta( $post_id, 'coreft_booking_limit', wp_kses( $_POST['coreft_booking_limit'], $allowed ) );
		update_post_meta( $post_id, 'coreft_booking_block_hours', wp_kses( $_POST['coreft_booking_block_hours'], $allowed ) );

		$booking_price = $_POST['coreft_booking_price'];
		$booking_price = str_replace(array(","), '.', $booking_price);
		if(strpos($booking_price, '.') === FALSE && $booking_price > 0) {
			$booking_price = $booking_price.'.00';
		}
		update_post_meta( $post_id, 'coreft_booking_price', wp_kses( $booking_price, $allowed ) );

		$coreft_booking_ticket = $_POST['coreft_booking_ticket'];
		update_post_meta( $post_id, 'coreft_booking_ticket', wp_kses( $coreft_booking_ticket, $allowed ) );
		
		update_post_meta( $post_id, 'coreft_timezone', wp_kses( $_POST['coreft_timezone'], $allowed ) );
		
		update_post_meta( $post_id, 'coreft_recurring_frecuency', wp_kses( $_POST['coreft_recurring_frecuency'], $allowed ) );
		
		
		if(is_array($coreftCalendar['custom_fields_counter'])) {
			$counter = 0;
			
			foreach($coreftCalendar['custom_fields_counter'] as $key) {
				update_post_meta( $post_id, 'coreft_custom_'.$coreftCalendar['custom_fields']['id'][$counter], wp_kses( $_POST['coreft_custom_'.$coreftCalendar['custom_fields']['id'][$counter]], $allowed ) );
				
				$counter++;		
			}
		}
		update_post_meta( $post_id, 'coreft_excerpt', wp_kses( $_POST['coreft_excerpt'], $allowed ) );

		
		update_post_meta( $post_id, 'coreft_link', wp_kses( $_POST['coreft_link'], $allowed ) );
		update_post_meta( $post_id, 'coreft_age_range', wp_kses( $_POST['coreft_age_range'], $allowed ) );
		update_post_meta( $post_id, 'coreft_use_link', wp_kses( $_POST['coreft_use_link'], $allowed ) );
		update_post_meta( $post_id, 'coreft_rtl', wp_kses( $_POST['coreft_rtl'], $allowed ) );
		update_post_meta( $post_id, 'coreft_color', wp_kses( $_POST['coreft_color'], $allowed ) );
		update_post_meta( $post_id, 'coreft_fb_event', wp_kses( $_POST['coreft_fb_event'], $allowed ) );
		update_post_meta( $post_id, 'coreft_share', wp_kses( $_POST['coreft_share'], $allowed ) );
		update_post_meta( $post_id, 'coreft_location', wp_kses( $_POST['coreft_location'], $allowed ) );
		update_post_meta( $post_id, 'coreft_organizer', wp_kses( $_POST['coreft_organizer'], $allowed ) );
		update_post_meta( $post_id, 'coreft_phone', wp_kses( $_POST['coreft_phone'], $allowed ) );
		update_post_meta( $post_id, 'coreft_video', wp_kses( $_POST['coreft_video'], $allowed ) );
		update_post_meta( $post_id, 'coreft_map', wp_kses( $_POST['coreft_map'], $allowed ) );
		update_post_meta( $post_id, 'coreft_map_lnlat', wp_kses( $_POST['coreft_map_lnlat'], $allowed ) );
		update_post_meta( $post_id, 'coreft_user_rate', wp_kses( $_POST['coreft_user_rate'], $allowed ) );
		update_post_meta( $post_id, 'coreft_featured_event', wp_kses( $_POST['coreft_featured_event'], $allowed ) );
		update_post_meta( $post_id, 'coreft_disable_sync', wp_kses( $_POST['coreft_disable_sync'], $allowed ) );
		update_post_meta( $post_id, 'coreft_rate', wp_kses( $_POST['coreft_rate'], $allowed ) );

		$old_date = get_post_meta( $post_id, 'coreft_date', true);
		$new_date_short = wp_kses( $_POST['coreft_date_y'] ."-".str_pad($_POST['coreft_date_m'], 2, "0", STR_PAD_LEFT)."-".str_pad($_POST['coreft_date_d'], 2, "0", STR_PAD_LEFT), $allowed);
		$new_date = $new_date_short. " " . $_POST['coreft_time_hours'] . ":" . $_POST['coreft_time_minutes'] . ":00";

		if(isset($old_date) && $old_date != "" && $old_date != $new_date) {
			$wpdb->update( 
				$table_name_booking, 
				array( 
					'event_date'	=> $new_date_short
				), 
				array( 
						'id_event' => $post_id,
						'event_date' => date("Y-m-d", strtotime($old_date))
					),
				array(  
					'%s'
				),
				array(  
					'%d',
					'%s'
				) 
			);
		}
		update_post_meta( $post_id, 'coreft_date', $new_date);
		update_post_meta( $post_id, 'coreft_end_time_hh', wp_kses( $_POST['coreft_end_time_hh'], $allowed ) );
		update_post_meta( $post_id, 'coreft_end_time_mm', wp_kses( $_POST['coreft_end_time_mm'], $allowed ) );
		
		$end_date = $_POST['coreft_end_date_y']."-".str_pad($_POST['coreft_end_date_m'], 2, "0", STR_PAD_LEFT)."-".str_pad($_POST['coreft_end_date_d'], 2, "0", STR_PAD_LEFT);
		if(strlen($end_date) < 10) {
			$end_date = '';
		}
		if($end_date == $_POST['coreft_date'] && $_POST['coreft_recurring_frecuency'] == 0) {
			$end_date = '';
		}
		update_post_meta( $post_id, 'coreft_end_date', wp_kses( $end_date, $allowed ) );
		update_post_meta( $post_id, 'coreft_exceptions', sanitize_text_field($_POST['coreft_exceptions']) );
		update_post_meta( $post_id, 'coreft_extra_dates',  sanitize_text_field($_POST['coreft_extra_dates']) );
		update_post_meta( $post_id, 'coreft_daily_every', sanitize_text_field($_POST['coreft_daily_every']) );
		update_post_meta( $post_id, 'coreft_daily_working_days', sanitize_text_field($_POST['coreft_daily_working_days']) );
		update_post_meta( $post_id, 'coreft_weekly_day', absint($_POST['coreft_weekly_day']) );
		update_post_meta( $post_id, 'coreft_weekly_every', absint($_POST['coreft_weekly_every']) );
		update_post_meta( $post_id, 'coreft_monthly_every', absint($_POST['coreft_monthly_every']) );
		update_post_meta( $post_id, 'coreft_monthly_position', sanitize_text_field($_POST['coreft_monthly_position']) );
		update_post_meta( $post_id, 'coreft_monthly_day', sanitize_text_field($_POST['coreft_monthly_day']) ) ;
		
		
		// Update the post excerpt
	    $wpdb->update( 
			$wpdb->posts, 
			array( 
				'post_excerpt'		=> wp_kses_post($_POST['coreft_excerpt'])
			), 
			array( 'ID' => $post_id ), 
			array( 
				'%s'
			),
			array( 
				'%d'
			) 
		);

	    
	    //wp_update_post( $excerpt_update );

		if(is_array($calendar_list) && !empty($calendar_list)) {
			$calendar_data = $wpdb->get_row( 
				$wpdb->prepare("
					SELECT booking_cancel_email_template, booking_cancel_email_enable 
					FROM ".$table_name_calendars. " 
					WHERE id = %d", $calendar_list[0]
				)
			);
		}

		if(is_array($_POST['coreft_booking_status'])) {
			foreach($_POST['coreft_booking_status'] as $booking_id => $booking_status) {
				$booking_id = absint($booking_id);
				$wpdb->update( 
					$table_name_booking, 
					array( 
						'status'		=> sanitize_text_field($booking_status),
						'cancel_reason' => sanitize_text_field($_POST['coreft_booking_cancel_reason'][$booking_id])
					), 
					array( 'id' => $booking_id ), 
					array( 
						'%s'
					),
					array( 
						'%d'
					) 
				);

				if($_POST['coreft_booking_cancel_send_mail'][$booking_id] && $calendar_data->booking_cancel_email_enable) {
					
					$booking_cancel_email_template = $calendar_data->booking_cancel_email_template;
					if($booking_cancel_email_template == '') {
						$booking_cancel_email_template = "Hi #USERNAME#,\n\nThe following booking has been canceled:\n\n#EVENT_DETAILS#\n\n#CANCEL_REASON#\n\nPlease contact us if you have questions.\n\nKind Regards.\n#SITE_NAME#";
					}
					
					add_filter( 'wp_mail_from_name', 'coreftCalendar_wp_mail_from_name' );
					add_filter( 'wp_mail_from', 'coreftCalendar_wp_mail_from' );
					$headers = array('Content-Type: text/html; charset=UTF-8');

					// Email to User
					
					if(isset($_POST['coreft_booking_email'][$booking_id])) {
						$booking_user_email = sanitize_email($_POST['coreft_booking_email'][$booking_id]);
						
						wp_mail( $booking_user_email, get_bloginfo('name'), apply_filters('coreft_booking_email_cancel', $booking_cancel_email_template, $booking_id), $headers );

					}
				}
			}
		}
	}	
}
add_action( 'save_post', 'coreftCalendar_meta_box_save' );

function coreftCalendar_excerpt_display( $post ) {
	global $coreftCalendar;
	
	$values = get_post_custom( $post->ID );
	$coreft_excerpt = isset( $values['coreft_excerpt'] ) ? $values['coreft_excerpt'][0] : '';

	wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
	
	?>
	<textarea name="coreft_excerpt" id="excerpt"><?php echo $coreft_excerpt?></textarea>
    <label class="coreft_ui_calendar_content_desc"><p><?php _e('Excerpts are optional hand-crafted summaries of your content that can be used in your theme.', 'coreftCalendar'); ?> <a href="https://codex.wordpress.org/Excerpt" target="_blank"><?php _e('Learn more about manual excerpts.', 'coreftCalendar'); ?></a></p></label>

    
	<?php
}

function coreftCalendar_events_display( $post ) {
	global $coreftCalendar, $wpdb, $table_prefix;
	
	$table_name_sd = $table_prefix.COREFT_CALENDAR_TABLE_SPECIAL_DATES;
	
	$values = get_post_custom( $post->ID );
	$coreft_link = isset( $values['coreft_link'] ) ? $values['coreft_link'][0] : '';
	$coreft_age_range = isset( $values['coreft_age_range'] ) ? $values['coreft_age_range'][0] : '';
	$coreft_color = isset( $values['coreft_color'] ) ? $values['coreft_color'][0] : '';
	$coreft_fb_event = isset( $values['coreft_fb_event'] ) ? $values['coreft_fb_event'][0] : '';
	$coreft_share = isset( $values['coreft_share'] ) ? $values['coreft_share'][0] : '';
	$coreft_location = isset( $values['coreft_location'] ) ? $values['coreft_location'][0] : '';
	$coreft_organizer = isset( $values['coreft_organizer'] ) ? $values['coreft_organizer'][0] : '';
	$coreft_phone = isset( $values['coreft_phone'] ) ? $values['coreft_phone'][0] : '';
	$coreft_video = isset( $values['coreft_video'] ) ? $values['coreft_video'][0] : '';
	$coreft_map = isset( $values['coreft_map'] ) ? $values['coreft_map'][0] : '';
	$coreft_map_lnlat = isset( $values['coreft_map_lnlat'] ) ? $values['coreft_map_lnlat'][0] : '';
	$coreft_user_rate = isset( $values['coreft_user_rate'] ) ? $values['coreft_user_rate'][0] : '';
	$coreft_featured_event = isset( $values['coreft_featured_event'] ) ? $values['coreft_featured_event'][0] : '';
	$coreft_disable_sync = isset( $values['coreft_disable_sync'] ) ? $values['coreft_disable_sync'][0] : '';
	$coreft_rate = isset( $values['coreft_rate'] ) ? $values['coreft_rate'][0] : '';
	$coreft_use_link = isset( $values['coreft_use_link'] ) ? $values['coreft_use_link'][0] : '';
	$coreft_rtl = isset( $values['coreft_rtl'] ) ? $values['coreft_rtl'][0] : '';

	wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
	
	if(isset($_GET['action']) && $_GET['action'] == 'edit') {
	?>
	<p class="misc-pub-section">
		<label for="coreft_disable_sync"><?php _e('Disable Sync?', 'coreftCalendar'); ?></label>
        
    	<input type="checkbox" value="1" name="coreft_disable_sync" id="coreft_disable_sync" <?php if($coreft_disable_sync) {?> checked="checked"<?php }?> />
    	<?php _e('If this event is being synced, you can disable the sync and make changes to the event.','coreftCalendar'); ?>
    </p> 

    <div class="clear"></div>
    <?php }?>
    <p class="misc-pub-section">
		<label for="coreft_featured_event"><?php _e('Featured Event?', 'coreftCalendar'); ?></label>
        
    	<input type="checkbox" value="1" name="coreft_featured_event" id="coreft_featured_event" <?php if($coreft_featured_event) {?> checked="checked"<?php }?> />
    	<?php _e('Display it first in some event lists.','coreftCalendar'); ?>
    </p> 
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_color"><?php _e('Color (optional)', 'coreftCalendar'); ?></label>
		<select name="coreft_color">
        	<option value=""><?php _e('None', 'coreftCalendar')?></option>
             <?php 
			$counter = 0;
			$querystr = "
			SELECT *
			FROM $table_name_sd 
			ORDER BY title ASC
			";
			$sp_dates_obj = $wpdb->get_results($querystr, OBJECT);
			foreach($sp_dates_obj as $sp_dates) {
			?>
            
            	<option value="<?php echo $sp_dates->id?>" <?php echo ($coreft_color == $sp_dates->id ? 'selected="selected"' : '')?>><?php echo $sp_dates->title?></option>
            
            <?php }?>
        </select>
        <label class="coreft_ui_calendar_content_desc"><?php _e('Select a color. To create a new one, go to the <a href="'.admin_url( 'admin.php?page=coreftCalendar-special' ).'" target="_blank">special dates</a> section','coreftCalendar'); ?></label>
	</p>
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_link" style="height:50px;"><?php _e('Link (optional)', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_link" size="80" id="coreft_link" value="<?php echo $coreft_link; ?>" placeholder="<?php _e('Introduce a URL','coreftCalendar'); ?>" />
		<br />
		<input type="checkbox" value="1" name="coreft_use_link" id="coreft_use_link" <?php if($coreft_use_link) {?> checked="checked"<?php }?> />
		<span class="coreft_data_desc"><?php _e('Use this url instead of the event single page?','coreftCalendar'); ?></span>
	</p>
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_fb_event"><?php _e('Facebook Event URL (optional)', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_fb_event" size="80" id="coreft_fb_event" value="<?php echo $coreft_fb_event; ?>" placeholder="<?php _e('Introduce a Facebook Page URL','coreftCalendar'); ?>" />
	</p>
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_age_range"><?php _e('Age Range (optional)', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_age_range" size="80" id="coreft_age_range" value="<?php echo $coreft_age_range; ?>" placeholder="<?php _e('The expected age range','coreftCalendar'); ?>" />
	</p>
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_phone"><?php _e('Phone (optional)', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_phone" size="80" id="coreft_phone" value="<?php echo $coreft_phone; ?>" placeholder="<?php _e('Introduce the Phone number','coreftCalendar'); ?>" />
	</p>
	<div class="clear"></div>
	<p class="misc-pub-section">
		<label for="coreft_video"><?php _e('Video URL (optional)', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_video" size="80" id="coreft_video" value="<?php echo $coreft_video; ?>" placeholder="<?php _e('Introduce a Youtube video URL','coreftCalendar'); ?>" />
	</p>
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_location"><?php _e('Location / Venue', 'coreftCalendar'); ?></label>
		<select name="coreft_location">
        	<option value=""><?php _e('None', 'coreftCalendar')?></option>
             <?php 
			$args = array(
			'posts_per_page'   => -1,
			'post_type'        => 'coreft-venues',
			'post_status'      => 'publish',
			'order'			   => 'ASC', 
			'orderby' 		   => 'title' 
			);

			$venues_list = get_posts($args);
			foreach($venues_list as $venue) {
			?>
            
            	<option value="<?php echo $venue->ID?>" <?php echo ($coreft_location == $venue->ID ? 'selected="selected"' : '')?>><?php echo $venue->post_title?></option>
            
            <?php }?>
        </select> &nbsp; <a href="post-new.php?post_type=coreft-venues" class="button" target="_blank"><?php _e('New Venue', 'coreftCalendar'); ?></a>
		<!--<input type="text" name="coreft_location" size="80" id="coreft_location" value="<?php echo $coreft_location; ?>" placeholder="<?php _e('Location to be displayed in the event list','coreftCalendar'); ?>" />-->
	</p>
    <div class="clear"></div>
    <p class="misc-pub-section">
		<label for="coreft_organizer"><?php _e('Organizer', 'coreftCalendar'); ?></label>
		<select name="coreft_organizer">
        	<option value=""><?php _e('None', 'coreftCalendar')?></option>
             <?php 
			$args = array(
			'posts_per_page'   => -1,
			'post_type'        => 'coreft-organizers',
			'post_status'      => 'publish',
			'order'			   => 'ASC', 
			'orderby' 		   => 'title' 
			);

			$organizers_list = get_posts($args);
			foreach($organizers_list as $organizer) {
			?>
            
            	<option value="<?php echo $organizer->ID?>" <?php echo ($coreft_organizer == $organizer->ID ? 'selected="selected"' : '')?>><?php echo $organizer->post_title?></option>
            
            <?php }?>
        </select> &nbsp; <a href="post-new.php?post_type=coreft-organizers" class="button" target="_blank"><?php _e('New Organizer', 'coreftCalendar'); ?></a>
	</p>
    <div class="clear"></div>
    

    <p class="misc-pub-section"> 
    	<label for="coreft_rtl"><?php _e('Right-to-left', 'coreftCalendar'); ?></label>
        <input type="checkbox" value="1" name="coreft_rtl" id="coreft_rtl" <?php if($coreft_rtl) {?> checked="checked"<?php }?> /> <?php _e(' (RTL in single page)','coreftCalendar'); ?>
        
	</p>
    <div class="clear"></div>
    
    <p class="misc-pub-section">
		<label for="coreft_user_rate"><?php _e('Rating (optional)', 'coreftCalendar'); ?></label>
        
		<select name="coreft_rate" id="coreft_rate">
        	<option value=""><?php _e('None', 'coreftCalendar'); ?></option>
            <option value="1" <?php echo $coreft_rate == 1 ? 'selected="selected"' : ''?>><?php _e('1 Star', 'coreftCalendar'); ?></option>
            <option value="1.5" <?php echo $coreft_rate == 1.5 ? 'selected="selected"' : ''?>><?php _e('1.5 Stars', 'coreftCalendar'); ?></option>
            <option value="2" <?php echo $coreft_rate == 2 ? 'selected="selected"' : ''?>><?php _e('2 Stars', 'coreftCalendar'); ?></option>
            <option value="2.5" <?php echo $coreft_rate == 2.5 ? 'selected="selected"' : ''?>><?php _e('2.5 Stars', 'coreftCalendar'); ?></option>
            <option value="3" <?php echo $coreft_rate == 3 ? 'selected="selected"' : ''?>><?php _e('3 Stars', 'coreftCalendar'); ?></option>
            <option value="3.5" <?php echo $coreft_rate == 3.5 ? 'selected="selected"' : ''?>><?php _e('3.5 Stars', 'coreftCalendar'); ?></option>
            <option value="4" <?php echo $coreft_rate == 4 ? 'selected="selected"' : ''?>><?php _e('4 Stars', 'coreftCalendar'); ?></option>
            <option value="4.5" <?php echo $coreft_rate == 4.5 ? 'selected="selected"' : ''?>><?php _e('4.5 Stars', 'coreftCalendar'); ?></option>
            <option value="5" <?php echo $coreft_rate == 5 ? 'selected="selected"' : ''?>><?php _e('5 Stars', 'coreftCalendar'); ?></option>
        </select> 
        <br><br>
    	<input type="checkbox" value="1" name="coreft_user_rate" id="coreft_user_rate" <?php if($coreft_user_rate) {?> checked="checked"<?php }?> /> <?php _e('Allow logged in users to rate events. (The manual rating will be disabled)','coreftCalendar'); ?>
    </p>    
    
    <div class="clear"></div>
    
    <?php 
	if(isset($coreftCalendar['custom_fields_counter']) && is_array($coreftCalendar['custom_fields_counter'])) {
		$counter = 0;
		foreach($coreftCalendar['custom_fields_counter'] as $key) {
	?>
    <p class="misc-pub-section">
		<label for="coreft_map"><?php echo $coreftCalendar['custom_fields']['name'][$counter]?></label>
        <?php if($coreftCalendar['custom_fields']['type'][$counter] == "checkbox") {?>
        <input type="checkbox" name="coreft_custom_<?php echo $coreftCalendar['custom_fields']['id'][$counter]?>" id="coreft_custom_<?php echo $coreftCalendar['custom_fields']['id'][$counter]?>" value="1" <?php if(get_post_meta($post->ID, 'coreft_custom_'.$coreftCalendar['custom_fields']['id'][$counter], true)) { ?> checked="checked" <?php }?> /> <?php echo htmlentities($coreftCalendar['custom_fields']['placeholder'][$counter])?>
        <?php } else { ?>
		<input type="text" name="coreft_custom_<?php echo $coreftCalendar['custom_fields']['id'][$counter]?>" size="80" id="coreft_custom_<?php echo $coreftCalendar['custom_fields']['id'][$counter]?>" value="<?php echo htmlentities(get_post_meta($post->ID, 'coreft_custom_'.$coreftCalendar['custom_fields']['id'][$counter], true)); ?>" placeholder="<?php echo htmlentities($coreftCalendar['custom_fields']['placeholder'][$counter])?>" />
        <?php }?>
	</p>
    <div class="clear"></div>
	<?php
			$counter++;
		}
	}
}

function coreftCalendar_booking_display( $post ) {
	global $wpdb, $table_prefix, $coreft_calendar_payments, $coreftCalendar;
	
	$table_name_booking = $table_prefix.COREFT_CALENDAR_TABLE_BOOKING;
	
	$values = get_post_custom( $post->ID );
	$coreft_enable_booking = isset( $values['coreft_enable_booking'] ) ? $values['coreft_enable_booking'][0] : '';
	$coreft_show_limit = isset( $values['coreft_show_limit'] ) ? $values['coreft_show_limit'][0] : '';
	$coreft_booking_limit = isset( $values['coreft_booking_limit'] ) ? $values['coreft_booking_limit'][0] : '';
	$coreft_booking_block_hours = isset( $values['coreft_booking_block_hours'] ) ? $values['coreft_booking_block_hours'][0] : '';
	$coreft_booking_price = isset( $values['coreft_booking_price'] ) ? $values['coreft_booking_price'][0] : '';
	$coreft_booking_continuous = isset( $values['coreft_booking_continuous'] ) ? $values['coreft_booking_continuous'][0] : '';
	$coreft_booking_ticket = isset( $values['coreft_booking_ticket'] ) ? $values['coreft_booking_ticket'][0] : '';
	$coreft_booking_ticket_arr = ($coreft_booking_ticket != "" ? explode(",", $coreft_booking_ticket) : '');

	wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
	?>
    <p class="misc-pub-section">
		<input type="checkbox" value="1" name="coreft_enable_booking" id="coreft_enable_booking" <?php if($coreft_enable_booking) {?> checked="checked"<?php }?> />  <?php _e('Enable Booking', 'coreftCalendar'); ?>
	</p>
    
    <p class="misc-pub-section">
		<label for="coreft_booking_limit"><?php _e('Limit (optional)', 'coreftCalendar'); ?></label>
		<input type="number" min="0" max="999999" name="coreft_booking_limit" size="50" id="coreft_booking_limit" value="<?php echo $coreft_booking_limit; ?>" placeholder="e.g 30" /><br />
        <label class="coreft_ui_calendar_content_desc"><?php _e('Introduce the maximum number of bookings allowed for this event.','coreftCalendar'); ?></label>
	</p>

	<div class="clear"></div>

	<p class="misc-pub-section">
		<label for="coreft_booking_block_hours"><?php _e('Block Hours (optional)', 'coreftCalendar'); ?></label>
		<input type="number" min="0" max="999999" name="coreft_booking_block_hours" size="50" id="coreft_booking_block_hours" value="<?php echo $coreft_booking_block_hours; ?>" placeholder="e.g 48" /> &nbsp; <?php _e('Hours', 'coreftCalendar')?><br />
        <label class="coreft_ui_calendar_content_desc"><?php _e('Block hours prior to the event date, so users can\'t book an event in those hours. i.e: If you need 2 days before approving a booking, you should set 48 hours.','coreftCalendar'); ?></label>
	</p>
	<div class="clear"></div>

	<p class="misc-pub-section">
		<label for="coreft_booking_continuous"><?php _e('Continuous booking?', 'coreftCalendar'); ?></label>
		<input type="checkbox" value="1" name="coreft_booking_continuous" id="coreft_booking_continuous" <?php if($coreft_booking_continuous) {?> checked="checked"<?php }?> />
        <label class="coreft_ui_calendar_content_desc"><?php _e('The attendees are registered automatically to all the event dates.','coreftCalendar'); ?></label>
	</p>
    
    <div class="clear"></div>

    <?php if ( is_plugin_active( 'woocommerce-coreft-calendar/woocommerce-coreft-calendar.php' ) ) {?>
    <p class="misc-pub-section">
		<label for="coreft_booking_ticket"><?php _e('Tickets (optional)', 'coreftCalendar'); ?><span class="coreft_info dashicons dashicons-info"><span><?php _e('Users will choose a ticket in the booking form and they will be redirected to the Woocommerce product page to purchase it.','coreftCalendar'); ?></span></span></label>

		<select name="" id="coreft_booking_ticket_select">
        	<option value=""><?php _e('Choose one...', 'coreftCalendar')?></option>
             <?php 
			$args = array(
			'posts_per_page'   => -1,
			'post_type'        => 'product',
			'post_status'      => 'publish',
			'order'			   => 'ASC', 
			'orderby' 		   => 'title',
			'tax_query' => array(
		        array(
		            'taxonomy' => 'product_type',
		            'field'    => 'slug',
		            'terms'    => 'coreft_ticket',
		        ),
		    )
			);

			$products = get_posts($args);
			foreach($products as $ticket) {
			?>
            
            	<option value="<?php echo $ticket->ID?>"><?php echo $ticket->post_title?></option>
            
            <?php }?>
        </select> 
        <input type="hidden" name="coreft_booking_ticket" id="coreft_booking_ticket" value="<?php echo $coreft_booking_ticket?>" />
        &nbsp; <a href="post-new.php?post_type=product" class="button" target="_blank"><?php _e('Create new Ticket', 'coreftCalendar'); ?></a>

        <br>
        <div class="coreft_ticket_list_wrap">
        <?php 
        if(is_array($coreft_booking_ticket_arr) && !empty($coreft_booking_ticket_arr) ) {
        	foreach($coreft_booking_ticket_arr as $key) {
        		if($key == "") { continue; }?>
        <span class="coreft_ticket_list" data-ticket-id="<?php echo $key?>"><?php echo get_the_title($key)?> <span class="dashicons dashicons-dismiss"></span></span>
        <?php }
    	}?>
        </div>
        <label class="coreft_ui_calendar_content_desc"><?php _e('Choose the booking ticket from Woocommerce.','coreftCalendar'); ?></label>
	</p>
    <div class="clear"></div>
    <?php } elseif(false) { ?>
    <div class="misc-pub-section">
		<label for="coreft_booking_ticket"><?php _e('Tickets (optional)', 'coreftCalendar'); ?><span class="coreft_info dashicons dashicons-info"><span><?php _e('Users will choose a ticket in the booking form and they will be redirected to the Woocommerce product page to purchase it.','coreftCalendar'); ?></span></span></label>
        
		<select name="coreft_booking_ticket"  disabled="disabled">
        	<option value=""><?php _e('None', 'coreftCalendar')?></option>
        </select><br />

        <div class="coreft_admin_errorCustom" style="float: left;"><p><?php _e('Notice: This feature requires the <a href="'.COREFT_CALENDAR_PAYMENTS_URL.'" target="_blank">
Woocommerce Event Tickets extension</a>.','coreftCalendar'); ?></p></div>
        <label class="coreft_ui_calendar_content_desc"><?php _e('Introduce the booking price. Leave blank to allow bookings for free.','coreftCalendar'); ?></label>
	</div>
    <div class="clear"></div>
    <?php }?>
    
    <h2><?php _e('List of Bookings', 'coreftCalendar'); ?>
    
    <?php if(current_user_can('edit_others_posts')) {?>
    
    <a class="button" style="float: right; margin-left: 10px;" href="<?php echo coreftCalendar_plugin_url('src/export_bookings.php?event_id='.$post->ID)?>"><?php _e('Export to Excel', 'coreftCalendar'); ?></a>

    <a class="button button-primary" style="float: right;"  href="javascript:void(0);" id="coreft_new_booking_show"><?php _e('Create Booking', 'coreftCalendar'); ?></a>

    <?php }?>
    
    </h2>

    <?php if(current_user_can('edit_others_posts')) {?>

    <div id="coreft_new_booking" style="display: none;">
	    <div class="misc-pub-section">
			<label for="coreft_new_booking_user"><?php _e('User', 'coreftCalendar'); ?></label>
			<select name="coreft_new_booking_user" id="coreft_new_booking_user">
	             <?php 
				$blogusers = get_users( 'orderby=nicename&number=2000' );

				foreach($blogusers as $user ) {
				?>
	            
	            	<option value="<?php echo $user->ID?>"><?php echo $user->display_name?></option>
	            
	            <?php }?>
	        </select> 
		</div>
	    <div class="clear"></div>

	    <div class="misc-pub-section">
			<label for="coreft_new_booking_phone"><?php _e('Phone', 'coreftCalendar'); ?></label>
	    	<input type="text" name="coreft_new_booking_phone" size="50" id="coreft_new_booking_phone" style="width:150px;" value="" />
	    </div>
	    <div class="clear"></div>
	    

	    <div class="misc-pub-section">
            <label for="coreft_new_booking_date"><?php _e('Date', 'coreftCalendar'); ?></label><br />
            <input type="text" readonly="readonly" name="coreft_new_booking_date" maxlength="10" onfocus="jQuery('.coreftCalendar_btn_getBookingEventDate').trigger('click');" id="coreft_new_booking_date" class="large-text" style="width:100px;" />
            
        </div>

        <script type="text/javascript">
			jQuery(document).ready(function() {
			jQuery("#coreft_new_booking_date").datepicker({
					
					showOn: "button",
					//isRTL: '.$isRTL.',
					buttonImage: "<?php echo coreftCalendar_plugin_url( 'images/admin/calendar.png' )?>",
					buttonImageOnly: false,
					minDate: 0,
					dateFormat: "yy-mm-dd",
					
				});
			});
	    </script>

	    <div class="misc-pub-section">
			<label for="coreft_new_booking_quantity"><?php _e('Quantity', 'coreftCalendar'); ?></label>
	    	<input type="number" min="0" max="9999" name="coreft_new_booking_quantity" size="50" id="coreft_new_booking_quantity" value="1" />
	    </div>
	    <div class="clear"></div>

	    <div class="misc-pub-section">
			<label for="coreft_new_booking_status"><?php _e('Status', 'coreftCalendar'); ?></label>
		    <select name="coreft_new_booking_status" id="coreft_new_booking_status">
				<option value=""><?php echo __( 'Completed', 'coreftCalendar' )?></option>
		        <option value="pending"><?php echo __( 'Pending', 'coreftCalendar' )?></option>
		        <option value="canceled_by_user"><?php echo __( 'Canceled By User', 'coreftCalendar' )?></option>
		        <option value="canceled"><?php echo __( 'Canceled', 'coreftCalendar' )?></option>
		    </select>
		</div>
	    <div class="clear"></div>
    	
    	<hr>

    	<a class="button button-primary" href="javascript:void(0);" data-coreftcalendar-eventid="<?php echo $post->ID?>" id="coreft_new_booking_submit"><?php _e('Send', 'coreftCalendar'); ?></a>

    	<a class="button" href="javascript:void(0);" id="coreft_new_booking_cancel"><?php _e('Cancel', 'coreftCalendar'); ?></a>
    </div>

    <?php }

    $id_list = $post->ID;
    if(function_exists('icl_object_id')) {
        global $sitepress;
		if(!empty($sitepress)) {
            $id_list_arr = array();
			$trid = $sitepress->get_element_trid($post->ID, 'post_coreft-events');
			$translation = $sitepress->get_element_translations($trid, 'post_coreft-events');

			foreach($translation as $key) {
				$id_list_arr[] = $key->element_id;
			}

			if(!empty($id_list_arr)) {
				$id_list = implode(",", $id_list_arr);
			}
		}
	}
	?>

    <p><?php _e('Add extra fields from the <a href="'.admin_url( 'admin.php?page=coreftCalendar-settings' ).'" target="_blank"> General settings</a>.','coreftCalendar'); ?></p>

    <div class="clear"></div>

    <select id="coreft_booking_filter_date">
    	<option value=""><?php _e('All Event Dates', 'coreftCalendar'); ?></option>
    	<?php
    	$querystr = "
            SELECT DISTINCT event_date
            FROM $table_name_booking
			WHERE id_event IN (".$id_list.")
            ORDER BY event_date ASC
            ";
            $bookings_obj = $wpdb->get_results($querystr, OBJECT);
            foreach($bookings_obj as $booking) {?>
            	<option value="<?php echo $booking->event_date?>"><?php echo date_i18n(get_option('date_format'), strtotime($booking->event_date))?></option>
            <?php
        	}
            ?>
    </select>
    <a class="button" href="javascript:void(0);" data-coreftcalendar-eventid="<?php echo $post->ID?>" id="coreft_booking_filter"><?php _e('Filter', 'coreftCalendar'); ?></a>
    <hr>
    
    <table class="widefat coreft_booking_table" cellpadding="0" cellspacing="0" id="coreft-sort-table">
        <thead>
            <tr style="cursor:default !important;">
                <th><?php _e('User Info','coreftCalendar'); ?></th>
                <th><?php _e('Booking Date','coreftCalendar'); ?></th>
                <th><?php _e('Event Date','coreftCalendar'); ?></th>
                <th><?php _e('Quantity','coreftCalendar'); ?></th>
                <th><?php _e('Comment','coreftCalendar'); ?> / <?php _e('Extra Fields','coreftCalendar'); ?></th>
                <th><?php _e('Status','coreftCalendar'); ?> <span class="coreft_info dashicons dashicons-info"><span><?php _e('If set in the calendar settings, the user will receive a notification when you cancel a booking.','coreftCalendar'); ?></span></span></th>
                <th></th>
             </tr>
        </thead>
        <tbody id="coreft-booking-list">
            <?php
            

			$querystr = "
            SELECT COUNT(*) as count
            FROM $table_name_booking
			WHERE id_event IN (".$id_list.")";
            $counter = $wpdb->get_row($querystr, OBJECT);
			
			$booking_count = 0;
            $querystr = "
            SELECT *
            FROM $table_name_booking
			WHERE id_event IN (".$id_list.")
            ORDER BY id DESC
			LIMIT 30
            ";
            $bookings_obj = $wpdb->get_results($querystr, OBJECT);
            foreach($bookings_obj as $booking) {
				if(is_numeric($booking->id_user) && $booking->id_user > 0) {
					//$userdata = FALSE;
					//$userdata = WP_User::get_data_by( 'id', $booking->id_user );

					$userdata = get_userdata($booking->id_user);
				} else {
					$userdata = new stdClass();
					$userdata->display_name = $booking->name;
					$userdata->user_email = $booking->email;	
				}
                ?>
            <tr>
                <td width="200"><?php echo $userdata->display_name?> <br>
                	<?php if($userdata->user_email != "") {?>
                	<span class="dashicons dashicons-email-alt"></span><input type="text" readonly="readonly" name="coreft_booking_email[<?php echo $booking->id?>]" class="coreft_booking_text" value="<?php echo $userdata->user_email?>" /><br>
                	<?php }?>

                	<?php if($booking->phone != "") {?>
                	<span class="dashicons dashicons-phone"></span><input type="text" readonly="readonly" name="coreft_booking_phone[<?php echo $booking->id?>]"  class="coreft_booking_text" value="<?php echo $booking->phone?>" />
                	<?php }?>
                </td>
                <td><?php echo date_i18n(get_option('date_format') . ' '. get_option('time_format'), strtotime($booking->booking_date))?></td>
                <td><?php echo date_i18n(get_option('date_format'), strtotime($booking->event_date))?></td>
                <td><?php echo $booking->quantity?></td>
                <td>
                	<?php if($booking->comment != "") {?>
                	<span class="dashicons dashicons-admin-comments"></span> <?php echo nl2br($booking->comment)?> <hr>
                	<?php }?>

                	<?php
                	$extra_fields = unserialize($booking->extra_fields);
                	if(!is_array($extra_fields)) 
                		$extra_fields = array();

                	$html = '';
                	
                	foreach($extra_fields as $key=>$value) {

                		$field_index = array_keys($coreftCalendar['booking_custom_fields']['id'], str_replace('coreft_custom_', '', $key));
                		
                		if(is_array($field_index)) {
	                		$field_index = $field_index[0];
	                	} else {
	                		$field_index = '';
	                	}

                		if($value != "" && is_numeric($field_index)) {
                			if($coreftCalendar['booking_custom_fields']['type'][$field_index] == 'checkbox') {
                				$value = __('Yes', 'coreftCalendar');
                			}
							$html .= '<div class="coreft_event_page_custom_fields">
										<strong>'.$coreftCalendar['booking_custom_fields']['name'][$field_index].': </strong>'.$value;
							$html .= '</div>';
						}

                	}
                	
                	echo $html;
					?>
				</td>
                <td>
                	<select name="coreft_booking_status[<?php echo $booking->id?>]" onchange="coreft_change_booking_status('<?php echo $booking->status?>', this);">
						<option value=""><?php echo __( 'Completed', 'coreftCalendar' )?></option>
                        <option value="pending" <?php if($booking->status == "pending") {?> selected="selected" <?php }?>><?php echo __( 'Pending', 'coreftCalendar' )?></option>
                        <option value="canceled_by_user" <?php if($booking->status == "canceled_by_user") {?> selected="selected" <?php }?>><?php echo __( 'Canceled By User', 'coreftCalendar' )?></option>
                        <option value="canceled" <?php if($booking->status == "canceled") {?> selected="selected" <?php }?>><?php echo __( 'Canceled', 'coreftCalendar' )?></option>
                    </select>
                    <div class="coreft_booking_cancel_reason_wrap" <?php if($booking->status == "canceled") {?> style="display:block;" <?php }?>>
	                    <input type="hidden" class="coreft_booking_cancel_send_mail" name="coreft_booking_cancel_send_mail[<?php echo $booking->id?>]" value="0" />

	                    <textarea class="coreft_booking_cancel_reason" name="coreft_booking_cancel_reason[<?php echo $booking->id?>]" placeholder="<?php echo __( 'Cancel Reason', 'coreftCalendar' )?>"><?php echo $booking->cancel_reason; ?></textarea>
                    </div>
                </td>
                <td><input type="button" value="<?php echo __( 'Delete', 'coreftCalendar' )?>" name="delete_booking" class="button-primary" onclick="if(confirm('<?php echo __( 'Are you sure that you want to remove this booking?', 'coreftCalendar' )?>')) { coreft_removeBooking(<?php echo $booking->id?>, this); }" /></td>
            </tr>
            <?php 
				$booking_count++;
			}
			
			if($booking_count == 0) {
				echo '<tr id="coreft_booking_list_zero"><td colspan="5"><p>'.__( 'No Booking Found.', 'coreftCalendar' ).'</p></td></tr>';
			}?>
        </tbody>
        <tfoot>
            <tr style="cursor:default !important;">
                <th><?php _e('User Info','coreftCalendar'); ?></th>
                <th><?php _e('Booking Date','coreftCalendar'); ?></th>
                <th><?php _e('Event Date','coreftCalendar'); ?></th>
                <th><?php _e('Quantity','coreftCalendar'); ?></th>
                <th><?php _e('Comment','coreftCalendar'); ?> / <?php _e('Extra Fields','coreftCalendar'); ?></th>
                <th><?php _e('Status','coreftCalendar'); ?></th>
                <th></th>
             </tr>
        </tfoot>
    </table>
    <script type="text/javascript">
    	function coreft_change_booking_status(original_status, new_status) {
    		jQuery(new_status).closest('td').find('.coreft_booking_cancel_reason_wrap').hide();
    		jQuery(new_status).closest('td').find('.coreft_booking_cancel_send_mail').val("0");

    		if(jQuery(new_status).val() == 'canceled') {
    			jQuery(new_status).closest('td').find('.coreft_booking_cancel_reason_wrap').show();

    			if(original_status != 'canceled') {
	    			jQuery(new_status).closest('td').find('.coreft_booking_cancel_send_mail').val("1");
	    		}

    		}
    	}
    </script>
    <?php 
	if($counter->count > 30) {?>
        <a class="button coreft-load-more" data-coreftcalendar-offset="30" data-coreftcalendar-eventid="<?php echo $post->ID?>" href="javascript:void(0);"><?php _e('Load More','coreftCalendar'); ?> (<span><?php echo ($counter->count - 30)?></span>)</a>
	<?php
	}
}

function coreftCalendar_venues_data_display( $post ) {
	global $wpdb, $table_prefix, $coreftCalendar;
	
	$values = get_post_custom( $post->ID );
	$coreft_venue_address = isset( $values['coreft_venue_address'] ) ? $values['coreft_venue_address'][0] : '';
	$coreft_venue_phone = isset( $values['coreft_venue_phone'] ) ? $values['coreft_venue_phone'][0] : '';
	$coreft_venue_link = isset( $values['coreft_venue_link'] ) ? $values['coreft_venue_link'][0] : '';
	$coreft_venue_map = isset( $values['coreft_venue_map'] ) ? $values['coreft_venue_map'][0] : '';
	$coreft_venue_map_lnlat = isset( $values['coreft_venue_map_lnlat'] ) ? $values['coreft_venue_map_lnlat'][0] : '';

	do_action( 'coreft_enqueue_admin', 1);

	wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );

	$map_lat = 0;
	$map_lng = 0;

	if($coreftCalendar['map_default_latlng'] != "") {
		
		$map_lnlat = explode(",", $coreftCalendar['map_default_latlng']);
		$map_lat = $map_lnlat[0];
		$map_lng = $map_lnlat[1];
	}

	if($coreft_venue_map_lnlat != "") {
		$map_lnlat = explode(",", $coreft_venue_map_lnlat);
		$map_lat = $map_lnlat[0];
		$map_lng = $map_lnlat[1];
	}

	?>
	
	<p class="misc-pub-section">
		<label for="coreft_venue_address"><?php _e('Address', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_venue_address" size="80" id="coreft_venue_address" value="<?php echo $coreft_venue_address; ?>" placeholder="<?php _e('Introduce the venue\'s address','coreftCalendar'); ?>" />
	</p>

	<p class="misc-pub-section">
		<label for="coreft_venue_phone"><?php _e('Phone', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_venue_phone" size="80" id="coreft_venue_phone" value="<?php echo $coreft_venue_phone; ?>" placeholder="<?php _e('Introduce the venue\'s phone','coreftCalendar'); ?>" />
	</p>

	<p class="misc-pub-section">
		<label for="coreft_venue_link"><?php _e('Link', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_venue_link" size="80" id="coreft_venue_link" value="<?php echo $coreft_venue_link; ?>" placeholder="<?php _e('The URL of the location\'s official website.','coreftCalendar'); ?>" />
	</p>

	<p class="misc-pub-section">
		<label for="coreft_venue_map"><?php _e('Google Map', 'coreftCalendar'); ?></label>
		<input type="text" name="coreft_venue_map" size="80" id="coreft_map" value="<?php echo $coreft_venue_map; ?>" placeholder="<?php _e('Introduce the country, city, address of the event. i.e: Spain, Madrid, Street x','coreftCalendar'); ?>" />
		<div class="clear"></div>
        <label for="coreft_venue_map_lnlat"><?php _e('Drag the marker to set a specific position (Lat, Lng)', 'coreftCalendar'); ?></label>
        <input type="text" name="coreft_venue_map_lnlat" size="80" id="coreft_map_lnlat" value="<?php echo $coreft_venue_map_lnlat; ?>" readonly="readonly" />
        <div class="coreft_calendar_date_event_map_overlay" onclick="style.pointerEvents='none'" style="height:400px; margin-top: -400px; top: 400px;"></div>
		<div id="mapCanvas" data-map-lat="<?php echo $map_lat?>" data-map-lng="<?php echo $map_lng?>" style="height: 400px;"></div>
	</p>
    <div class="clear"></div>

	<?php
	
}

function coreftCalendar_events_side_display( $post ) {
	global $wpdb, $table_prefix;
	$table_name_calendars = $table_prefix.COREFT_CALENDAR_TABLE_CALENDARS;
	
	require_once (dirname (__FILE__) . '/../src/base.class.php');
	
	$values = get_post_custom( $post->ID );
	$coreft_all_day = isset( $values['coreft_all_day'] ) ? $values['coreft_all_day'][0] : '0';
	$coreft_tbc = isset( $values['coreft_tbc'] ) ? $values['coreft_tbc'][0] : '0';
	$coreft_hide_time = isset( $values['coreft_hide_time'] ) ? $values['coreft_hide_time'][0] : '0';
	$coreft_id_calendar = isset( $values['coreft_id_calendar'] ) ? $values['coreft_id_calendar'][0] : '';
	$coreft_end_time_hh = isset( $values['coreft_end_time_hh'] ) ? $values['coreft_end_time_hh'][0] : '';
	$coreft_end_time_mm = isset( $values['coreft_end_time_mm'] ) ? $values['coreft_end_time_mm'][0] : '';
	$coreft_date = isset( $values['coreft_date'] ) ? $values['coreft_date'][0] : '';
	$coreft_end_date = isset( $values['coreft_end_date'] ) ? $values['coreft_end_date'][0] : '';
	$coreft_exceptions = isset( $values['coreft_exceptions'] ) ? $values['coreft_exceptions'][0] : '';
	$coreft_extra_dates = isset( $values['coreft_extra_dates'] ) ? $values['coreft_extra_dates'][0] : '';
	$coreft_recurring_frecuency = isset( $values['coreft_recurring_frecuency'] ) ? $values['coreft_recurring_frecuency'][0] : '0';
	$coreft_timezone = isset( $values['coreft_timezone'] ) ? $values['coreft_timezone'][0] : '';
	$coreft_daily_every = isset( $values['coreft_daily_every'] ) ? $values['coreft_daily_every'][0] : '1';
	$coreft_daily_working_days = isset( $values['coreft_daily_working_days'] ) ? $values['coreft_daily_working_days'][0] : '0';
	$coreft_weekly_day = isset( $values['coreft_weekly_day'][0] ) && !empty($values['coreft_weekly_day'][0]) ? unserialize($values['coreft_weekly_day'][0]) : array();
	$coreft_weekly_every = isset( $values['coreft_weekly_every'] ) ? $values['coreft_weekly_every'][0] : '1';
	$coreft_monthly_every = isset( $values['coreft_monthly_every'] ) ? $values['coreft_monthly_every'][0] : '1';
	$coreft_monthly_position = isset( $values['coreft_monthly_position'] ) ? $values['coreft_monthly_position'][0] : '';
	$coreft_monthly_day = isset( $values['coreft_monthly_day'] ) ? $values['coreft_monthly_day'][0] : '';
	
	if(!is_array($coreft_weekly_day)) { $coreft_weekly_day = array(); }
	
	do_action( 'coreft_enqueue_admin', 1);
		
	wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
	?>
    <div id="misc-publishing-actions">
        <div class="misc-pub-section">
            <label for="coreft_id_calendar"><?php _e('Calendar', 'coreftCalendar'); ?><span class="coreft_info dashicons dashicons-info"><span style="display:none;"><?php _e('Assign this event to one or more calendars. Select multiple calendars pressing "ctrl".', 'coreftCalendar'); ?></span></span></label><br />
            <input type="hidden" name="coreft_id_calendar" id="coreft_id_calendar" value="<?php echo $coreft_id_calendar?>" />
            <select name="coreft_id_calendar_tmp[]" id="coreft_id_calendar_tmp" multiple="multiple" style="width:100%;" onchange="coreft_update_cal_list(this);">
                <?php
				$count = 0;
                $querystr = "
                SELECT *
                FROM $table_name_calendars
                ORDER BY title ASC
                ";
                $calendars_obj = $wpdb->get_results($querystr, OBJECT);
                foreach($calendars_obj as $calendar) {
                ?>
                    <option value="<?php echo $calendar->id?>" <?php if((in_array($calendar->id, explode(',', $coreft_id_calendar))) || (empty($coreft_id_calendar) && count($calendars_obj) == 1 && $count == 0)) { ?> selected="selected"<?php }?>><?php echo $calendar->title?></option>
                <?php 
					$count++;
				}?>
            </select>
            <script type="text/javascript">
            function coreft_update_cal_list(el) {
				var option_all = jQuery("#coreft_id_calendar_tmp option:selected").map(function () {
					return jQuery(this).val();
				}).get().join(',');
				
				jQuery('#coreft_id_calendar').val(option_all);
				
			}
			<?php if(empty($coreft_id_calendar) && count($calendars_obj) == 1) {?>
			coreft_update_cal_list(jQuery('#coreft_id_calendar_tmp'));
			<?php }?>
            </script>
        </div>
        <div class="misc-pub-section">
            <label for="coreft_date" class="coreft_label_head"><?php _e('Date', 'coreftCalendar'); ?> <span class="coreft_date_format">Y-m-d</span></label><br />
            <input type="number" min="1" max="9999" maxlength="4" name="coreft_date_y" style="max-width: 70px;" id="coreft_date_y" value="<?php echo $coreft_date != '' ? date("Y", strtotime($coreft_date)) : current_time('Y')?>" placeholder="----" />
            <input type="number" min="1" max="12" maxlength="2" name="coreft_date_m" style="max-width: 50px;" id="coreft_date_m" value="<?php echo $coreft_date != '' ? date("m", strtotime($coreft_date)) : current_time('m')?>" placeholder="--" />
            <input type="number" min="1" max="31" maxlength="2" name="coreft_date_d" style="max-width: 50px;" id="coreft_date_d" value="<?php echo $coreft_date != '' ? date("d", strtotime($coreft_date)) : current_time('d')?>" placeholder="--" /><br />

            <div class="coreft_calendar_clear"></div>

        </div>
        <div class="misc-pub-section misc-pub-tbc">
            <input type="checkbox" name="coreft_tbc" id="coreft_tbc" value="1" <?php echo ($coreft_tbc ? 'checked="checked"' : ''); ?> />
            <label for="coreft_tbc"><span class="coreft_info dashicons dashicons-info"><span style="display:none;"><?php _e('The date won\'t be displayed to users, but you would need to set a start date to show the event in the upcoming events listings.' ,'coreftCalendar'); ?></span></span> <?php _e('To be confirmed', 'coreftCalendar'); ?></label>
        </div>
        <div class="misc-pub-section misc-pub-start-time">
            <label for="coreft_time_hours" class="coreft_label_head"><?php _e('Start Time', 'coreftCalendar'); ?></label><br />
            <select name="coreft_time_hours" id="coreft_time_hours" style="width:80px;">
                <?php for($i = 0; $i <= 23; $i++) {
					if(strpos(get_option('time_format'), "A")  !== false || strpos(get_option('time_format'), "a")  !== false) {
						$hour = str_pad(($i > 12 ? $i - 12 : ($i == '00' ? '12' : $i)), 2, "0", STR_PAD_LEFT). ' '.date('A', mktime($i, 0));
					} else {
						$hour = str_pad($i, 2, "0", STR_PAD_LEFT);
					}
					?>
                    <option value="<?php echo str_pad($i, 2, "0", STR_PAD_LEFT)?>" <?php if(date("H", strtotime($coreft_date)) == str_pad($i, 2, "0", STR_PAD_LEFT)) {?> selected="selected" <?php }?>><?php echo $hour?></option>
                <?php }?>
            </select>
            <select name="coreft_time_minutes" id="coreft_time_minutes" style="width:50px;">
                <?php for($i = 0; $i <= 59; $i += 5) {?>
                    <option value="<?php echo str_pad($i, 2, "0", STR_PAD_LEFT)?>" <?php if(date("i", strtotime($coreft_date)) == str_pad($i, 2, "0", STR_PAD_LEFT)) {?> selected="selected" <?php }?>><?php echo str_pad($i, 2, "0", STR_PAD_LEFT)?></option>
                <?php }?>
            </select>
            &nbsp; <input type="checkbox" name="coreft_hide_time" class="checkbox" id="coreft_hide_time" value="1" <?php if($coreft_hide_time) {?> checked="checked" <?php }?> /> <?php _e('Hide Time','coreftCalendar'); ?>
            <div class="coreft_calendar_clear"></div>
        </div>
        <div class="misc-pub-section misc-pub-end-time">
            <label for="coreft_end_time_hh" class="coreft_label_head"><?php _e('End Time', 'coreftCalendar'); ?></label><br />
            <select name="coreft_end_time_hh" id="coreft_end_time_hh" style="width:80px;">
            	<option value="">--</option>
                <?php for($i = 0; $i <= 23; $i++) {
					if(strpos(get_option('time_format'), "A")  !== false || strpos(get_option('time_format'), "a")  !== false) {
						$hour = str_pad(($i > 12 ? $i - 12 : ($i == '00' ? '12' : $i)), 2, "0", STR_PAD_LEFT). ' '.date('A', mktime($i, 0));
					} else {
						$hour = str_pad($i, 2, "0", STR_PAD_LEFT);
					}
					?>
                    <option value="<?php echo str_pad($i, 2, "0", STR_PAD_LEFT)?>" <?php if($coreft_end_time_hh != "" & str_pad($coreft_end_time_hh, 2, "0", STR_PAD_LEFT) == str_pad($i, 2, "0", STR_PAD_LEFT)) {?> selected="selected" <?php }?>><?php echo $hour?></option>
                <?php }?>
            </select>
            <select name="coreft_end_time_mm" id="coreft_end_time_mm" style="width:50px;">
            	<option value="">--</option>
                <?php for($i = 0; $i <= 59; $i += 5) {?>
                    <option value="<?php echo str_pad($i, 2, "0", STR_PAD_LEFT)?>" <?php if($coreft_end_time_mm != "" & str_pad($coreft_end_time_mm, 2, "0", STR_PAD_LEFT) == str_pad($i, 2, "0", STR_PAD_LEFT)) {?> selected="selected" <?php }?>><?php echo str_pad($i, 2, "0", STR_PAD_LEFT)?></option>
                <?php }?>
            </select>
            <div class="coreft_calendar_clear"></div>
        </div>

        <div class="misc-pub-section misc-pub-timezone">
        	<label for="coreft_timezone" class="coreft_label_head"><?php _e('Select a Timezone', 'coreftCalendar'); ?></label>
            <select name="coreft_timezone" id="coreft_timezone">

            	<?php //if($coreft_timezone == "") {
            		$current_offset = get_option('gmt_offset');
					$tzstring = get_option('timezone_string');
					if ( empty($tzstring) ) { // Create a UTC+- zone if no timezone string exists
						$check_zone_info = false;
						if ( 0 == $current_offset )
							$tzstring = 'UTC+0';
						elseif ($current_offset < 0)
							$tzstring = 'UTC' . $current_offset;
						else
							$tzstring = 'UTC+' . $current_offset;
					}

            		//$coreft_timezone = $tzstring;
            	//}
				if($coreft_timezone != "") {
            	?>
            	<option value=""><?php _e('Default', 'coreftCalendar'); ?> (<?php echo $tzstring?>)</option>
            	<?php }?>
                <?php echo wp_timezone_choice($coreft_timezone); ?>
            </select>
            <div class="coreft_calendar_clear"></div>
        </div>
        
        <div class="misc-pub-section misc-pub-all-day">
            <input type="checkbox" name="coreft_all_day" id="coreft_all_day" value="1" <?php echo ($coreft_all_day ? 'checked="checked"' : ''); ?> />
            <label for="coreft_all_day"><?php _e('Set if the event is all the day.', 'coreftCalendar'); ?></label>
        </div>
        <div class="misc-pub-section misc-pub-frequency">
        	<label for="coreft_recurring_frecuency" class="coreft_label_head"><?php _e('Select a frequency', 'coreftCalendar'); ?></label>
            <select name="coreft_recurring_frecuency" id="coreft_recurring_frecuency" onchange="coreft_update_frequency(this.value);">
                <option value="0" <?php if($coreft_recurring_frecuency == 0) {?> selected="selected" <?php }?>><?php _e('None','coreftCalendar'); ?></option>
                <option value="1" <?php if($coreft_recurring_frecuency == 1) {?> selected="selected" <?php }?>><?php _e('Daily','coreftCalendar'); ?></option>
                <option value="2" <?php if($coreft_recurring_frecuency == 2) {?> selected="selected" <?php }?>><?php _e('Weekly','coreftCalendar'); ?></option>
                <option value="3" <?php if($coreft_recurring_frecuency == 3) {?> selected="selected" <?php }?>><?php _e('Monthly','coreftCalendar'); ?></option>
                <option value="4" <?php if($coreft_recurring_frecuency == 4) {?> selected="selected" <?php }?>><?php _e('Yearly','coreftCalendar'); ?></option>
            </select>
            <div class="coreft_calendar_clear"></div>
        </div>
        
        <div class="misc-pub-section coreft_daily_frequency" style="display:none;">
			<div id="coreft_daily_every_div"><?php _e('Every','coreftCalendar'); ?> <input type="number" min="1" max="99" style="width:50px;" maxlength="2" name="coreft_daily_every" id="coreft_daily_every" value="<?php echo $coreft_daily_every?>" /> <?php _e('day(s)','coreftCalendar'); ?></div>
            <div id="coreft_daily_working_days_div"><input type="checkbox" name="coreft_daily_working_days" id="coreft_daily_working_days" onclick="coreft_check_daily_working_days(this);" <?php if($coreft_daily_working_days == 1) {?> checked="checked"<?php }?> value="1" /><?php _e('All working days','coreftCalendar'); ?></div>
        </div>
        <div class="misc-pub-section coreft_weekly_frequency" style="display:none;">
			<?php _e('Repeat every','coreftCalendar'); ?> <input type="number" min="1" max="99" style="width:50px;" maxlength="2" name="coreft_weekly_every" value="<?php echo $coreft_weekly_every?>" /> <?php _e('week(s) on:','coreftCalendar'); ?>
            <br /><br />
            <input type="checkbox" value="1" name="coreft_weekly_day[]" <?php if(in_array(1, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Mon','coreftCalendar'); ?><br />
            <input type="checkbox" value="2" name="coreft_weekly_day[]" <?php if(in_array(2, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Tue','coreftCalendar'); ?><br />
            <input type="checkbox" value="3" name="coreft_weekly_day[]" <?php if(in_array(3, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Wed','coreftCalendar'); ?><br />
            <input type="checkbox" value="4" name="coreft_weekly_day[]" <?php if(in_array(4, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Thu','coreftCalendar'); ?><br />
            <input type="checkbox" value="5" name="coreft_weekly_day[]" <?php if(in_array(5, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Fri','coreftCalendar'); ?><br />
            <input type="checkbox" value="6" name="coreft_weekly_day[]" <?php if(in_array(6, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Sat','coreftCalendar'); ?><br />
            <input type="checkbox" value="7" name="coreft_weekly_day[]" <?php if(in_array(7, $coreft_weekly_day)) {?> checked="checked" <?php }?> /> &nbsp; <?php _e('Sun','coreftCalendar'); ?>
        </div>
        <div class="misc-pub-section coreft_monthly_frequency" style="display:none;">
			<?php _e('Repeat every','coreftCalendar'); ?> <input type="number" min="1" max="99" style="width:50px;" maxlength="2" name="coreft_monthly_every" value="<?php echo $coreft_monthly_every?>" /> <?php _e('month(s) on:','coreftCalendar'); ?>
            <br /><br />
            <select name="coreft_monthly_position" id="coreft_monthly_position" style="width:90px;">
	            <option value=""><?php _e('','coreftCalendar'); ?></option>
                <option value="first" <?php if($coreft_monthly_position == 'first') {?> selected="selected" <?php }?>><?php _e('First','coreftCalendar'); ?></option>
                <option value="second" <?php if($coreft_monthly_position == 'second') {?> selected="selected" <?php }?>><?php _e('Second','coreftCalendar'); ?></option>
                <option value="third" <?php if($coreft_monthly_position == 'third') {?> selected="selected" <?php }?>><?php _e('Third','coreftCalendar'); ?></option>
                <option value="fourth" <?php if($coreft_monthly_position == 'fourth') {?> selected="selected" <?php }?>><?php _e('Fourth','coreftCalendar'); ?></option>
                <option value="last" <?php if($coreft_monthly_position == 'last') {?> selected="selected" <?php }?>><?php _e('Last','coreftCalendar'); ?></option>
            </select>
            
            <select name="coreft_monthly_day" id="coreft_monthly_day" style="width:150px;">
            <option value=""><?php _e('','coreftCalendar'); ?></option>
	            <option value="monday" <?php if($coreft_monthly_day == 'monday') {?> selected="selected" <?php }?>><?php _e('Monday','coreftCalendar'); ?></option>
                <option value="tuesday" <?php if($coreft_monthly_day == 'tuesday') {?> selected="selected" <?php }?>><?php _e('Tuesday','coreftCalendar'); ?></option>
                <option value="wednesday" <?php if($coreft_monthly_day == 'wednesday') {?> selected="selected" <?php }?>><?php _e('Wednesday','coreftCalendar'); ?></option>
                <option value="thursday" <?php if($coreft_monthly_day == 'thursday') {?> selected="selected" <?php }?>><?php _e('Thursday','coreftCalendar'); ?></option>
                <option value="friday" <?php if($coreft_monthly_day == 'friday') {?> selected="selected" <?php }?>><?php _e('Friday','coreftCalendar'); ?></option>
                <option value="saturday" <?php if($coreft_monthly_day == 'saturday') {?> selected="selected" <?php }?>><?php _e('Saturday','coreftCalendar'); ?></option>
                <option value="sunday" <?php if($coreft_monthly_day == 'sunday') {?> selected="selected" <?php }?>><?php _e('Sunday','coreftCalendar'); ?></option>
            </select>
            <div class="coreft_calendar_clear"></div>
        </div>
        
        <div class="misc-pub-section coreft_frequency_options" style="display:none;">
			<label for="coreft_exceptions"><?php _e('Exceptions','coreftCalendar'); ?></label> <input type="text" name="coreft_exceptions" id="coreft_exceptions" value="<?php echo $coreft_exceptions?>" />
            <label class="coreft_ui_calendar_content_desc"><?php _e('Add dates to exclude from the recurring event frequency. Format YYYY-MM-DD. i.e: ','coreftCalendar'); ?><?php echo date('Y')?>-12-24,<?php echo date('Y')?>-12-25,<?php echo date('Y')?>-12-31</label>
        </div>
        
        <div class="misc-pub-section">
            <label for="coreft_end_date" class="coreft_label_head"><?php _e('End Date', 'coreftCalendar'); ?> <span class="coreft_date_format">Y-m-d</span></label><br />

            <input type="number" min="<?php echo current_time('Y') - 2?>" max="9999" maxlength="4" name="coreft_end_date_y" style="max-width: 70px;" id="coreft_end_date_y" value="<?php echo $coreft_end_date != '' ? date("Y", strtotime($coreft_end_date)) : ''?>" placeholder="----" />
            <input type="number" min="1" max="12" maxlength="2" name="coreft_end_date_m" style="max-width: 50px;" id="coreft_end_date_m" value="<?php echo $coreft_end_date != '' ? date("m", strtotime($coreft_end_date)) : ''?>" placeholder="--" />
            <input type="number" min="1" max="31" maxlength="2" name="coreft_end_date_d" style="max-width: 50px;" id="coreft_end_date_d" value="<?php echo $coreft_end_date != '' ? date("d", strtotime($coreft_end_date)) : ''?>" placeholder="--" /><br />
            

            <label class="coreft_ui_calendar_content_desc"><?php _e('Select the end date. A frequency option must be selected.','coreftCalendar'); ?></label>
            <div class="coreft_calendar_clear"></div>
        </div>
        
        <div class="misc-pub-section">
			<label for="coreft_extra_dates" class="coreft_label_head"><?php _e('Extra Dates','coreftCalendar'); ?></label> <input type="text" name="coreft_extra_dates" id="coreft_extra_dates" value="<?php echo $coreft_extra_dates?>" />
            <label class="coreft_ui_calendar_content_desc"><?php _e('Add extra dates to include in the calendar. Format YYYY-MM-DD. i.e: ','coreftCalendar'); ?><?php echo date('Y')?>-12-24,<?php echo date('Y')?>-12-25,<?php echo date('Y')?>-12-31</label>
        </div>
    </div>
    <script type="text/javascript">
    	jQuery('#coreft_timezone option[value=""]').text("<?php _e('Default', 'coreftCalendar'); ?> (<?php echo $tzstring?>)");

		function coreft_check_daily_working_days(chk) {
			if(jQuery(chk).is(':checked')) {
				jQuery('#coreft_daily_every_div').hide();
			} else {
				jQuery('#coreft_daily_every_div').show();
			}
		}
		
		function coreft_update_frequency(val) {
			jQuery('.coreft_frequency_options').hide();
			jQuery('.coreft_daily_frequency').hide();
			jQuery('.coreft_weekly_frequency').hide();
			jQuery('.coreft_monthly_frequency').hide();
			
			switch(val) {
				case "1":
					jQuery('.coreft_daily_frequency').show();
					jQuery('.coreft_weekly_frequency').hide();
					jQuery('.coreft_monthly_frequency').hide();
					jQuery('.coreft_frequency_options').show();
					break;	
				case "2":
					jQuery('.coreft_daily_frequency').hide();
					jQuery('.coreft_weekly_frequency').show();
					jQuery('.coreft_monthly_frequency').hide();
					jQuery('.coreft_frequency_options').show();
					break;	
				case "3":
					jQuery('.coreft_daily_frequency').hide();
					jQuery('.coreft_weekly_frequency').hide();
					jQuery('.coreft_monthly_frequency').show();
					jQuery('.coreft_frequency_options').show();
					break;	
				case "4":
					jQuery('.coreft_daily_frequency').hide();
					jQuery('.coreft_weekly_frequency').hide();
					jQuery('.coreft_monthly_frequency').hide();
					jQuery('.coreft_frequency_options').show();
					break;	
			}
		}
		coreft_update_frequency("<?php echo $coreft_recurring_frecuency?>");
		coreft_check_daily_working_days(jQuery('#coreft_daily_working_days'));
	</script>

	<?php
}

/*
function coreftcalendar_price_column_register( $columns ) {
	$columns['start_date'] = __( 'Date' );
 
	return $columns;
}
add_filter( 'manage_edit-post_columns', 'coreftcalendar_price_column_register' );
*/

add_action('manage_posts_columns', 'coreftcalendar_add_column_to_events_list');
function coreftcalendar_add_column_to_events_list( $posts_columns ) {
    global $typenow;
    if ($typenow != 'coreft-events' && $typenow != 'coreft-venues') return $posts_columns;

	if ($typenow == 'coreft-venues') {
		$new_posts_columns = array();
        $index = 0;
        foreach($posts_columns as $key => $posts_column) {
            if ($key=='date') {
                $new_posts_columns['address'] = null;
                $new_posts_columns['link'] = null;
                $new_posts_columns['events'] = null;
            }
            $new_posts_columns[$key] = $posts_column;
        }

		$new_posts_columns['address'] = __('Address', 'coreftCalendar');
		$new_posts_columns['link'] = __('Link', 'coreftCalendar');
		$new_posts_columns['events'] = __('Events', 'coreftCalendar');
	}

    if ($typenow == 'coreft-events') {
		if (!isset($posts_columns['author'])) {
	        $new_posts_columns = $posts_columns;
	    } else {
	        $new_posts_columns = array();
	        $index = 0;
	        foreach($posts_columns as $key => $posts_column) {
	            if ($key=='author')
	                $new_posts_columns['calendar'] = null;
	            $new_posts_columns[$key] = $posts_column;
	        }
	    }
	    $new_posts_columns['calendar'] = __('Calendar', 'coreftCalendar');
		$new_posts_columns['start_date'] = __('Date', 'coreftCalendar');
		$new_posts_columns['end_date'] = __('End Date', 'coreftCalendar');
		$new_posts_columns['frequency'] = __('Frequency', 'coreftCalendar');
		$new_posts_columns['bookings'] = __('Bookings', 'coreftCalendar');
	}

    return $new_posts_columns;
}

add_action('manage_posts_custom_column', 'coreftcalendar_column_for_events_list',10,2);
function coreftcalendar_column_for_events_list( $column_id,$post_id ) {
    global $typenow, $current_user, $wpdb, $coreftCalendar, $table_prefix;
    
    if ($typenow=='coreft-venues') {
    	switch ($column_id) {
			case 'address':
				$address = get_post_meta($post_id, 'coreft_venue_address', true);
				echo $address;
				break;
			case 'link':
				$link = get_post_meta($post_id, 'coreft_venue_link', true);
				echo $link;
				break;
			case 'events':
				$args = array( 
					'posts_per_page' => -1, 
					'fields' => 'ids',
					'no_found_rows' => true,
					'post_type' => 'coreft-events',
					'meta_key' => 'coreft_location',
					'meta_value' => $post_id
				);

				$events = '0';

			    $events_count = get_posts( $args );

				$events = count($events_count);
				echo $events;
				break;
		}
    }

    if ($typenow=='coreft-events') {
		
        switch ($column_id) {
			case 'calendar':
				$id_calendar = get_post_meta($post_id, 'coreft_id_calendar', true);
				
				if (isset($id_calendar)) {
					
					$cal_list = explode(",", $id_calendar);
					require_once (dirname (__FILE__) . '/../src/base.class.php');
					
					$calendar = "";
					
					$count = 0;
					foreach($cal_list as $key) {
						$coreftCalendar_class = new CoreftCalendar( true, $key );
						
						if($count > 0) {
							$calendar .= ' - ';	
						}
						
						$calendar .= '<a href="'.admin_url('admin.php?page=coreftCalendar-admin&edit='.$key).'">' . $coreftCalendar_class->getCalendarName() . '</a>';
						$count++;
					}
					echo $calendar;
				}
				break;
			
			case 'start_date':
				$coreft_date = get_post_meta($post_id, 'coreft_date', true);
				echo '<abbr title="'.date_i18n(get_option('date_format'), strtotime($coreft_date)).' '.date_i18n(get_option('time_format'), strtotime($coreft_date)).'">'.date_i18n(get_option('date_format'), strtotime($coreft_date)).' '.date_i18n(get_option('time_format'), strtotime($coreft_date)).'</abbr><br>'.ucfirst(get_post_status($post_id));
				break;
			
			case 'end_date':
				$end_time_hh = get_post_meta($post_id, 'coreft_end_time_hh', true);
				$end_time_mm = get_post_meta($post_id, 'coreft_end_time_mm', true);
				
				if(empty($end_time_hh)) $end_time_hh = '00';
				if(empty($end_time_mm)) $end_time_mm = '00';
				
				$coreft_end_date = get_post_meta($post_id, 'coreft_end_date', true);
				$coreft_date = $coreft_end_date . ' ' . $end_time_hh . ':' . $end_time_mm . ':00';

				if($coreft_end_date != "" && $coreft_end_date != "0000-00-00") {
					echo '<abbr title="'.date_i18n(get_option('date_format'), strtotime($coreft_date)).' '.($end_time_hh != "" ? date_i18n(get_option('time_format'), strtotime($coreft_date)) : '' ).'">'.date_i18n(get_option('date_format'), strtotime($coreft_date)).' '.($end_time_hh != "" ? date_i18n(get_option('time_format'), strtotime($coreft_date)) : '' ).'</abbr>';
				}
				break;
			
			case 'frequency':
				$frequency = get_post_meta($post_id, 'coreft_recurring_frecuency', true);
				if($frequency != "" && $frequency > 0) {
					switch($frequency) {
						case 1: 
							echo __('Daily', 'coreftCalendar');
							break;	
						case 2: 
							echo __('Weekly', 'coreftCalendar');
							break;	
						case 3: 
							echo __('Monthly', 'coreftCalendar');
							break;	
						case 4: 
							echo __('Yearly', 'coreftCalendar');
							break;	
						
					}
				}
				break;
			case 'bookings':
				$table_name_booking = $table_prefix.COREFT_CALENDAR_TABLE_BOOKING;
				
				$querystr = "
					SELECT SUM(quantity) as counter
					FROM ".$table_name_booking."
					WHERE id_event = ".$post_id." AND status <> 'pending'
					";
				$bookings_obj = $wpdb->get_row($querystr, OBJECT);
				
				echo '<abbr>'.$bookings_obj->counter.'</abbr>';

				break;
        }		
    }
}

function coreftcalendar_price_column_register_sortable( $columns ) {
	global $typenow;
    if ($typenow != 'coreft-events') return $columns;

	$columns['start_date'] = 'start_date';
 
	return $columns;
}
add_filter( 'manage_edit-coreft-events_sortable_columns', 'coreftcalendar_price_column_register_sortable' );

function coreftcalendar_price_column_orderby( $vars ) {
	global $typenow;
	if ($typenow != 'coreft-events') return $vars;
	if ( isset( $vars['orderby'] ) && 'start_date' == $vars['orderby'] ) {
		$vars = array_merge( $vars, array(
			'meta_key' => 'coreft_date',
			'orderby' => 'meta_value_num meta_value'
		) );
	}
 
	return $vars;
}
add_filter( 'request', 'coreftcalendar_price_column_orderby' );

function coreftcalendar_manage_columns($columns) {
	global $typenow, $wpdb;

	if ($typenow=='coreft-events') {
		unset($columns['comments']);
		unset($columns['date']);
	}
    return $columns;
}
add_filter('manage_posts_columns' , 'coreftcalendar_manage_columns');

add_action('restrict_manage_posts','coreftcalendar_restrict_events_by_calendar');
function coreftcalendar_restrict_events_by_calendar() {
    global $typenow;
    global $wp_query;
	global $wpdb, $table_prefix;
	$table_name_calendars = $table_prefix.COREFT_CALENDAR_TABLE_CALENDARS;
	
    if ($typenow=='coreft-events') {
        ?>
        <select name="coreft_id_calendar" id="coreft_id_calendar">
            <option value=""><?php _e('Show all calendars...','coreftCalendar'); ?></option>
            <?php
            $querystr = "
            SELECT *
            FROM $table_name_calendars
            ORDER BY title ASC
            ";
            $calendars_obj = $wpdb->get_results($querystr, OBJECT);
			if(is_array($calendars_obj)) {
				foreach($calendars_obj as $calendar) {
            ?>
                <option value="<?php echo $calendar->id?>" <?php if($calendar->id == $_GET['coreft_id_calendar']) { ?> selected="selected"<?php }?>><?php echo $calendar->title?></option>
            <?php }
			}?>
        </select>

        <select name="coreft_events_category" id="coreft_events_category">
            <option value=""><?php _e('Show all categories...','coreftCalendar'); ?></option>
            <?php
            $categories = get_categories(array('taxonomy' => 'coreft_events_category', 'hide_empty' => 0));
							$category_color = "";
							if(!empty($categories)) {
								foreach ( $categories as $cat){
            ?>
                <option value="<?php echo $cat->slug?>" <?php if($cat->slug == $_GET['coreft_events_category']) { ?> selected="selected"<?php }?>><?php echo $cat->cat_name?></option>
            <?php }
			}?>
        </select>
        <?php
    }
}

add_filter('parse_query','coreftcalendar_convert_filter');
function coreftcalendar_convert_filter($query) {
    global $pagenow;
    $qv = &$query->query_vars;
    if ($pagenow=='edit.php' &&
            isset($qv['post_type']) && $qv['post_type']=='coreft-events' &&
            isset($_GET['coreft_id_calendar']) && is_numeric($_GET['coreft_id_calendar'])) {
		$query->query_vars['meta_query'] = array( 
			relation => 'OR',
			array('key' => "coreft_id_calendar", "value" => '(,'.coreftSanitizeData($_GET['coreft_id_calendar']).',)', 'compare' => 'REGEXP'),
			array('key' => "coreft_id_calendar", "value" => '(,'.coreftSanitizeData($_GET['coreft_id_calendar']).')$', 'compare' => 'REGEXP'),
			array('key' => "coreft_id_calendar", "value" => '^('.coreftSanitizeData($_GET['coreft_id_calendar']).',)', 'compare' => 'REGEXP'),
			array('key' => "coreft_id_calendar", "value" => coreftSanitizeData($_GET['coreft_id_calendar']))
		);
        //$query->query_vars['meta_value'] = $_GET['coreft_id_calendar'];
		
		if ( isset( $_GET['orderby'] ) && 'start_date' == $_GET['orderby'] ) {
			$query->query_vars['meta_key'] = "coreft_date";
			unset($query->query_vars['meta_value']);
			$query->query_vars['orderby'] = 'meta_value_num meta_value';
		}
    }
	
    if ( is_admin() && $pagenow=='edit.php' && isset($_GET['ADMIN_FILTER_FIELD_NAME']) && $_GET['ADMIN_FILTER_FIELD_NAME'] != '') {
        $query->query_vars['meta_key'] = coreftSanitizeData($_GET['ADMIN_FILTER_FIELD_NAME']);
    if (isset($_GET['ADMIN_FILTER_FIELD_VALUE']) && $_GET['ADMIN_FILTER_FIELD_VALUE'] != '')
        $query->query_vars['meta_value'] = coreftSanitizeData($_GET['ADMIN_FILTER_FIELD_VALUE']);
    }
}