<?php // Hook for adding admin menus
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
if ( is_admin() ){ // admin actions
  add_action('admin_menu', 'coreftCalendar_settings');
  add_action('admin_init', 'coreftCalendar_register_mysettings');
} 

//Adds settings to Network Settings
add_filter( 'wpmu_options'       , 'coreftCalendar_show_network_settings' );
add_action( 'update_wpmu_options', 'coreftCalendar_save_network_settings' );

// function for adding settings page to wp-admin
function coreftCalendar_settings() {
global $coreftCalendar, $current_user;
    
	if(!is_array($coreftCalendar['user_roles'])) { $coreftCalendar['user_roles'] = array(); }
	if(!in_array(coreftCalendar_get_user_role(), $coreftCalendar['user_roles']) && coreftCalendar_get_user_role() != "administrator" && !is_super_admin($current_user->ID)) { return; }
    // Add a new submenu under Options:

    $args = array( 'posts_per_page' => 21, 'post_type'=> 'coreft-events', 'post_status' => 'pending' );

    $pending = get_posts( $args );
    $pending_counter = 0;
    $pending_counter = count($pending);

	$br = add_menu_page( 'Event Calendar', __('Event Calendar', 'coreftCalendar'). ( $pending_counter > 0 ? '<span class="update-plugins count-'.($pending_counter > 20 ? '20+' : $pending_counter).'"><span class="plugin-count">'.($pending_counter > 20 ? '20+' : $pending_counter).'</span></span>' : '' ), 'edit_posts','coreftCalendar-admin', 'coreftCalendar_calendars_page', COREFT_CALENDAR_URL.'images/icon.png' );
	add_submenu_page('coreftCalendar-admin', __('Categories', 'coreftCalendar'), __('Categories', 'coreftCalendar'), 'edit_posts', 'edit-tags.php?taxonomy=coreft_events_category');
	if(coreftCalendar_get_user_role() != 'editor' && coreftCalendar_get_user_role() != 'contributor' && coreftCalendar_get_user_role() != 'author') {
		add_submenu_page('coreftCalendar-admin', __('Calendars', 'coreftCalendar'), __('Calendars', 'coreftCalendar'), 'edit_posts', 'coreftCalendar-admin', 'coreftCalendar_calendars_page');
		add_submenu_page('coreftCalendar-admin', __('Special Dates', 'coreftCalendar'), __('Color Settings', 'coreftCalendar'), 'edit_posts', 'coreftCalendar-special', 'coreftCalendar_special_page');
		add_submenu_page('coreftCalendar-admin', __('Settings', 'coreftCalendar'), __('Settings', 'coreftCalendar'), 'edit_posts', 'coreftCalendar-settings', 'coreftCalendar_settings_page');
	    add_submenu_page('coreftCalendar-admin', __('Shortcode Generator', 'coreftCalendar'), __('Shortcodes', 'coreftCalendar'), 'edit_posts', 'coreftCalendar-custom-shortcodes', 'coreftCalendar_custom_shortcodes_page');
	}
	//add_submenu_page('coreftCalendar-admin', __('Documentation', 'coreftCalendar'), __('Documentation', 'coreftCalendar'), 'edit_posts', 'coreftCalendar-documentation', 'coreftCalendar_documentation_page');
	
	//add_submenu_page('coreftCalendar-admin', __('Display Data in Event Page', 'coreftCalendar'), __('Display Data in Event Page', 'coreftCalendar'), 'edit_posts', 'coreftCalendar-eventdata', 'coreftCalendar_eventdata_page');
}

add_filter( 'parent_file', 'coreft_catalog_set_current_menu' );

function coreft_catalog_set_current_menu( $parent_file ) {
	global $submenu_file, $current_screen, $pagenow, $taxonomy;

	# Set the submenu as active/current while anywhere in your Custom Post Type
	if ( in_array($current_screen->post_type, array('coreft-events', 'coreft-venues', 'coreft-organizers')) ||  ($current_screen->post_type === 'post' && $taxonomy === 'coreft_events_category')) {

		if ( $pagenow == 'post.php' ) {
			$submenu_file = 'edit.php?post_type=' . $current_screen->post_type;
		}

		if ( $current_screen->post_type !== 'post' && ($pagenow == 'edit-tags.php' || $pagenow == 'term.php') ) {
			$submenu_file = 'edit-tags.php?taxonomy=' . $taxonomy . '&post_type=' . $current_screen->post_type;
		} elseif($current_screen->post_type === 'post') {
		    $submenu_file = 'edit-tags.php?taxonomy=' . $taxonomy;
		}

		$parent_file = 'coreftCalendar-admin';

	}

	return $parent_file;

}

function coreftCalendar_get_user_role() {
	global $current_user;

	$user_roles = $current_user->roles;
	$user_role = array_shift($user_roles);

	return $user_role;
}

function coreftCalendar_show_network_settings() {
    $settings = coreftCalendar_get_network_settings();
?>
    <h3><?php _e( 'Event Calendar Settings' ); ?></h3>
    <table id="menu" class="form-table">
        <?php
            foreach ( $settings as $setting ) :
        ?>

        <tr valign="top">
            <th scope="row"><?php echo $setting['name']; ?></th>
            <td>
                <input type="<?php echo $setting['type'];?>" name="coreftCalendar[<?php echo $setting['id']; ?>]" value="<?php echo esc_attr( get_site_option( $setting['id'] ) ); ?>" />
                <br /><?php echo $setting['desc']; ?>
            </td>
        </tr>
        <?php
    endforeach;
    echo '</table>';
}

function coreftCalendar_save_network_settings() {
    $posted_settings  = array_map( 'sanitize_text_field', coreftSanitizeData($_POST['coreftCalendar']) );

    foreach ( $posted_settings as $name => $value ) {
        update_site_option( $name, $value );
    }
}

function coreftCalendar_get_network_settings() {

    $settings[] = array(
                'id'   => 'coreft-purchase-code',
                'name' => __( 'Purchase Code', 'coreftCalendar' ),
                'desc' => __('Introduce the purchase code to get automatic updates.','coreftCalendar'),
                'type' => 'text',
                'size' => 'regular'
    );

    return apply_filters( 'plugin_settings', $settings );
}

include(dirname(__FILE__) . '/calendars.php');
include(dirname(__FILE__) . '/events-meta.php');
require_once(COREFT_CALENDAR_PATH.'views/admin/colors.php');
require_once(COREFT_CALENDAR_PATH.'views/admin/settings.php');
require_once(COREFT_CALENDAR_PATH.'views/admin/shortcodes.php');

// This function displays the page content for the Settings submenu

function coreftCalendar_register_mysettings() { // whitelist options
  register_setting( 'coreftCalendar-group', 'coreftCalendar_options', 'coreftCalendar_validate' );
}

function coreftCalendar_validate($input) {
	global $coreftCalendar;
	
	//if ( isset($_SERVER['HTTP_REFERER']) && (strpos($_SERVER['HTTP_REFERER'], 'coreftCalendar-settings') > 0) ) {
		//return $input;
	//}
	//die(print_r($input));
	//die(print_r($input));
	if(!$input['rtl_support']) 
		$input['rtl_support'] = 0;
	
	if(!$input['exclude_from_search']) 
		$input['exclude_from_search'] = 0;
		
	if(!$input['exclude_gmaps']) 
		$input['exclude_gmaps'] = 0;

    if(!$input['disable_rewrite_rules']) 
        $input['disable_rewrite_rules'] = 0;

    if(!$input['disable_reminders']) 
        $input['disable_reminders'] = 0;
	
    if(!$input['remove_expired_enable']) 
        $input['remove_expired_enable'] = 0;

    if(!$input['recaptcha_enable']) 
        $input['recaptcha_enable'] = 0;

	if(!$input['event_single_enable']) 
		$input['event_single_enable'] = 0;
		
	if(!$input['paypal_enable']) 
		$input['paypal_enable'] = 0;
		
	if(!$input['paypal_testmode']) 
		$input['paypal_testmode'] = 0;
		
	if(!$input['stripe_enable']) 
		$input['stripe_enable'] = 0;
		
	if(!$input['stripe_testmode']) 
		$input['stripe_testmode'] = 0;
		
	$coreftCalendar['custom_fields_counter'] = '';
    $coreftCalendar['booking_custom_fields_counter'] = '';
		
	$input = coreftCalendar_array_merge($coreftCalendar, $input);
    return $input;
}

function coreftCalendar_array_merge($paArray1, $paArray2)
{
    if (!is_array($paArray1) or !is_array($paArray2)) { return $paArray2; }
    foreach ($paArray2 AS $sKey2 => $sValue2)
    {
		if($sKey2 == "user_roles") {
			$paArray1[$sKey2] = array(); 	
		}
        $paArray1[$sKey2] = coreftCalendar_array_merge(@$paArray1[$sKey2], $sValue2);
    }
    return $paArray1;
}
?>